@@ -27,7 +27,10 @@
 #include <string.h>
 #include <stdlib.h> // for 'system'
 #ifdef ENABLE_MP3
+#   include <id3tag.h>
+#   ifdef ENABLE_ID3LIB
 #   include <id3.h>
+#   endif
 #endif
 #include <errno.h>
 
@@ -42,7 +45,7 @@
 #endif
 
 #ifdef WIN32
-#   include "win32dep.h"
+#   include "win32/win32dep.h"
 #endif
 
 
@@ -155,6 +158,7 @@ void Show_About_Window (void)
             {"    - doutor zero ",                  _("(Brazilian Portuguese translation)")},
             {"    - Luchezar P. Petkov ",           _("(Bulgarian translation)")},
             {"    - Yang Jinsong ",                 _("(Chinese translation)")},
+            {"    - Yuval Hager ",                  _("(Hebrew translation)")},
             {NULL,NULL}
             };
 
@@ -199,6 +203,8 @@ void Show_About_Window (void)
             "    - Alexey Illarionov\n"
             "    - Der Humph\n"
             "    - Emmanuel Brun\n"
+            "    - Maarten Maathuis\n"
+            "    - Pierre Dumuid\n"
             "";
 
 
@@ -267,14 +273,28 @@ void Show_About_Window (void)
     gtk_box_pack_start(GTK_BOX(VBox),Label,FALSE,TRUE,0);
 
 #ifdef ENABLE_MP3 // FIX ME : should separate gtk and id3lib
-    sprintf(temp,_("(using: GTK+ %d.%d.%d and id3lib %d.%d.%d)"),GTK_MAJOR_VERSION,GTK_MINOR_VERSION,
-        GTK_MICRO_VERSION,ID3LIB_MAJOR_VERSION,ID3LIB_MINOR_VERSION,ID3LIB_PATCH_VERSION);
+    sprintf(temp,_("(using: GTK+ %d.%d.%d)"),GTK_MAJOR_VERSION,GTK_MINOR_VERSION,
+        GTK_MICRO_VERSION);
     Label = gtk_label_new(temp);
     gtk_box_pack_start(GTK_BOX(VBox),Label,FALSE,TRUE,0);
 #endif
 
-#ifndef ENABLE_MP3
-    Label = gtk_label_new(_("(MP3 file support disabled)"));
+#ifdef ENABLE_MP3
+    sprintf(temp, _("(MP3 file support enabled using: libid3tag %s)"), ID3_VERSION);
+    Label = gtk_label_new(temp);
+    gtk_box_pack_start(GTK_BOX(VBox),Label,FALSE,TRUE,0);
+#if (defined ENABLE_ID3LIB) 
+    sprintf(temp, _("(ID3v2.3 tags support enabled using: id3lib %d.%d.%d)"),
+        ID3LIB_MAJOR_VERSION, ID3LIB_MINOR_VERSION, ID3LIB_PATCH_VERSION);
+    Label = gtk_label_new(temp);
+    gtk_box_pack_start(GTK_BOX(VBox),Label,FALSE,TRUE,0);
+#else
+    Label = gtk_label_new(_("(ID3v2.3 tags  support disabled)"));
+    gtk_box_pack_start(GTK_BOX(VBox),Label,FALSE,TRUE,0);
+#endif
+#else
+    sprintf(temp, _("(MP3 file support disabled)"));
+    Label = gtk_label_new(temp);
     gtk_box_pack_start(GTK_BOX(VBox),Label,FALSE,TRUE,0);
 #endif
 
@@ -283,6 +303,11 @@ void Show_About_Window (void)
     gtk_box_pack_start(GTK_BOX(VBox),Label,FALSE,TRUE,0);
 #endif
 
+#ifndef ENABLE_SPEEX
+    Label = gtk_label_new(_("(Speex file support disabled)"));
+    gtk_box_pack_start(GTK_BOX(VBox),Label,FALSE,TRUE,0);
+#endif
+
 #ifndef ENABLE_FLAC
     Label = gtk_label_new(_("(FLAC file support disabled)"));
     gtk_box_pack_start(GTK_BOX(VBox),Label,FALSE,TRUE,0);
@@ -293,6 +318,11 @@ void Show_About_Window (void)
     gtk_box_pack_start(GTK_BOX(VBox),Label,FALSE,TRUE,0);
 #endif
 
+#ifndef ENABLE_WAVPACK
+    Label = gtk_label_new(_("(WavPack file support disabled)"));
+    gtk_box_pack_start(GTK_BOX(VBox),Label,FALSE,TRUE,0);
+#endif
+
     /* Insert a blank line */
     Label = gtk_label_new("");
     gtk_box_pack_start(GTK_BOX(VBox),Label,FALSE,TRUE,0);
@@ -328,6 +358,7 @@ void Show_About_Window (void)
     gtk_misc_set_padding(GTK_MISC(Label),2,2);
     gtk_label_set_line_wrap(GTK_LABEL(Label),TRUE);
     gtk_container_add(GTK_CONTAINER(Frame),Label);
+    gtk_container_resize_children(GTK_CONTAINER(Frame));
 
 
     /*
@@ -430,19 +461,20 @@ void Show_About_Window (void)
     {
         gint first_version = 0;
 
-        while(fgets(temp,sizeof(temp),file))
+        while (fgets(temp,sizeof(temp),file))
         {
             if (temp[strlen(temp)-1]=='\n')
                 temp[strlen(temp)-1]='\0';
             if (temp[strlen(temp)-1]=='\r')
                 temp[strlen(temp)-1]='\0';
 
+            // Convert line to UTF-8
             if (!g_utf8_validate(temp, -1, NULL))
                 tmp = convert_string(temp, "iso-8859-1", "utf-8",TRUE);
             else
                 tmp = g_strdup(temp);
 
-            if (tmp && tmp[0]!=' ')
+            if (tmp && tmp[0]!=' ') // If first character is a space => 1rst line after title
             {
                 first_version++;
                 // To set to bold the title of the version and to red the first version
@@ -465,6 +497,7 @@ void Show_About_Window (void)
                                                              tmp, -1,
                                                              "monospace", "blue_foreground", NULL);
             }
+
             gtk_text_buffer_insert(TextBuffer, &iter, "\n", -1);
             g_free(tmp);
         }
