@@ -33,9 +33,10 @@
 
 #include "charset.h"
 #include "setting.h"
+#include "log.h"
 
 #ifdef WIN32
-    #include "win32dep.h"
+    #include "win32/win32dep.h"
 #endif
 
 
@@ -81,11 +82,11 @@ const CharsetInfo charset_trans_array[] = {
     {N_("Turkish (IBM-857)"),                 "IBM857"        },
     {N_("Turkish (ISO-8859-9)"),              "ISO-8859-9"    },
     {N_("Turkish (Windows-1254)"),            "windows-1254"  },
-    {N_("Unicode (UTF-7)"),                   "UTF-7"         },
+    //{N_("Unicode (UTF-7)"),                   "UTF-7"         },
     {N_("Unicode (UTF-8)"),                   "UTF-8"         },
 
-    {N_("Unicode (UTF-16BE)"),                "UTF-16BE"      },
-    {N_("Unicode (UTF-16LE)"),                "UTF-16LE"      },
+    //{N_("Unicode (UTF-16BE)"),                "UTF-16BE"      },
+    //{N_("Unicode (UTF-16LE)"),                "UTF-16LE"      },
     //{N_("Unicode (UTF-32BE)"),                "UTF-32BE"      },
     //{N_("Unicode (UTF-32LE)"),                "UTF-32LE"      },
 
@@ -183,8 +184,11 @@ Charset_Insert_Locales_Init (void)
 
     /* "C" is plain ascii */
     insert_locales (encodings, "ASCII", "C", NULL);
-
+#if WIN32
     insert_locales (encodings, "windows-1256", "ar", NULL); // 2006.12.31 - For testing with Arabic
+#else
+    insert_locales (encodings, "ISO-8859-6", "ar", NULL);
+#endif
     insert_locales (encodings, "ARMSCII-8", "by", NULL);
     insert_locales (encodings, "BIG5", "zh_TW", NULL);
     insert_locales (encodings, "CP1251", "be", "bg", NULL);
@@ -198,15 +202,31 @@ Charset_Insert_Locales_Init (void)
     /*insert_locales (encodings, "GEORGIAN-ACADEMY", NULL);*/
     insert_locales (encodings, "GEORGIAN-PS", "ka", NULL);
     insert_locales (encodings, "ISO-8859-1", "br", "ca", "da", "de", "en", "es", "eu", "fi", "fr", "gl", "it", "nl", "wa", "no", "pt", "pt", "sv", NULL);
+#if WIN32
+    insert_locales (encodings, "windows-1250", "cs", "hr", "hu", "pl", "ro", "sk", "sl", "sq", "sr", NULL);
+#else
     insert_locales (encodings, "ISO-8859-2", "cs", "hr", "hu", "pl", "ro", "sk", "sl", "sq", "sr", NULL);
+#endif
     insert_locales (encodings, "ISO-8859-3", "eo", NULL);
     insert_locales (encodings, "ISO-8859-5", "mk", "sp", NULL);
+#if WIN32
+    insert_locales (encodings, "windows-1253", "el", NULL);
+#else
     insert_locales (encodings, "ISO-8859-7", "el", NULL);
+#endif
+#if WIN32
+    insert_locales (encodings, "windows-1254", "tr", NULL);
+#else
     insert_locales (encodings, "ISO-8859-9", "tr", NULL);
+#endif
     insert_locales (encodings, "ISO-8859-13", "lt", "lv", "mi", NULL);
     insert_locales (encodings, "ISO-8859-14", "ga", "cy", NULL);
     insert_locales (encodings, "ISO-8859-15", "et", NULL);
+#if WIN32
+    insert_locales (encodings, "windows-1251", "ru", NULL);
+#else
     insert_locales (encodings, "KOI8-R", "ru", NULL);
+#endif
     insert_locales (encodings, "KOI8-U", "uk", NULL);
     if (check_locale ("TCVN-5712")) {
         insert_locales (encodings, "TCVN-5712", "vi", NULL);
@@ -214,6 +234,9 @@ Charset_Insert_Locales_Init (void)
         insert_locales (encodings, "TCVN", "vi", NULL);
     }
     insert_locales (encodings, "TIS-620", "th", NULL);
+#if WIN32
+    insert_locales (encodings, "windows-1255", "he", NULL);
+#endif
     /*insert_locales (encodings, "VISCII", NULL);*/
 }
 
@@ -376,7 +399,7 @@ gchar *convert_string_1 (const gchar *string, gssize length, const gchar *from_c
         gchar *escaped_str = g_strescape(string, NULL);
         if (display_error)
         {
-            g_warning("convert_string(): Failed conversion from charset '%s' to '%s'. "
+            Log_Print("convert_string(): Failed conversion from charset '%s' to '%s'. "
                       "String '%s'. Errcode %d (%s).\n",
                       from_codeset, to_codeset, escaped_str, error->code, error->message);
         }
@@ -425,15 +448,15 @@ gchar *convert_to_utf8 (const gchar *string)
         const gchar *usercharset;
         gchar *escaped_str = g_strescape(string, NULL);
         g_get_charset(&usercharset);
-        g_warning("convert_to_utf8(): Failed conversion from charset '%s'. "
+        Log_Print("convert_to_utf8(): Failed conversion from charset '%s'. "
                   "String '%s'. Errcode %d (%s).\n",
                   usercharset, escaped_str, error->code, error->message);
         g_free(escaped_str);
 
         if (g_utf8_validate(string, -1, NULL))
-            g_warning("convert_to_utf8(): String was valid UTF-8.\n");
+            Log_Print("convert_to_utf8(): String was valid UTF-8.\n");
         else
-            g_warning("convert_to_utf8(): String was INVALID UTF-8.\n");
+            Log_Print("convert_to_utf8(): String was INVALID UTF-8.\n");
 
         g_error_free(error);
         return g_strdup(string);
@@ -457,15 +480,15 @@ gchar *convert_from_utf8 (const char *string)
         const gchar *usercharset;
         gchar *escaped_str = g_strescape(string, NULL);
         g_get_charset(&usercharset);
-        g_warning("convert_from_utf8(): Failed conversion to charset '%s'. "
+        Log_Print("convert_from_utf8(): Failed conversion to charset '%s'. "
                   "String '%s'. Errcode %d (%s).\n",
                   usercharset, escaped_str, error->code, error->message);
         g_free(escaped_str);
 
         if (g_utf8_validate(string, -1, NULL))
-            g_warning("convert_from_utf8(): String was valid UTF-8.\n");
+            Log_Print("convert_from_utf8(): String was valid UTF-8.\n");
         else
-            g_warning("convert_from_utf8(): String was INVALID UTF-8.\n");
+            Log_Print("convert_from_utf8(): String was INVALID UTF-8.\n");
 
         g_error_free(error);
         return g_strdup(string);
@@ -516,7 +539,7 @@ gchar *filename_to_display (const gchar *string)
         if (!ret)
         {
             gchar *escaped_str = g_strescape(string, NULL);
-            g_warning(_("The filename '%s' couldn't be converted into UTF-8 (%s).\n"),
+            Log_Print(_("The filename '%s' couldn't be converted into UTF-8 (%s).\n"),
                         escaped_str, error && error->message ? error->message : _("Invalid UTF-8"));
             g_clear_error(&error);
 
@@ -615,7 +638,7 @@ gchar *filename_from_display (const gchar *string)
     {
         // Conversion KO!
         gchar *escaped_str = g_strescape(string, NULL);
-        g_warning(_("The UTF-8 string '%s' couldn't be converted into filename encoding (%s)\n"),
+        Log_Print(_("The UTF-8 string '%s' couldn't be converted into filename encoding (%s)\n"),
                     escaped_str, error && error->message ? error->message : _("Invalid UTF-8"));
         g_clear_error(&error);
 
@@ -679,7 +702,7 @@ gchar *Try_To_Validate_Utf8_String (const gchar *string)
         if (!ret)
         {
             gchar *escaped_str = g_strescape(string, NULL);
-            g_warning(_("The string '%s' couldn't be converted into UTF-8 (%s).\n"),
+            Log_Print(_("The string '%s' couldn't be converted into UTF-8 (%s).\n"),
                         escaped_str, error && error->message ? error->message : _("Invalid UTF-8"));
             g_clear_error(&error);
 
@@ -766,25 +789,25 @@ gboolean test_conversion_charset (const gchar *from, const gchar *to)
         /*// Error in conversion
         if (error && error->code == G_CONVERT_ERROR_NO_CONVERSION)
         {
-            g_print("Conversion error from '%s' to '%s' (G_CONVERT_ERROR_NO_CONVERSION)\n",from,to);
+            Log_Print("Conversion error from '%s' to '%s' (G_CONVERT_ERROR_NO_CONVERSION)",from,to);
         } else if (error && error->code == G_CONVERT_ERROR_ILLEGAL_SEQUENCE)
         {
-            g_print("Conversion error from '%s' to '%s' (G_CONVERT_ERROR_ILLEGAL_SEQUENCE)\n",from,to);
+            Log_Print("Conversion error from '%s' to '%s' (G_CONVERT_ERROR_ILLEGAL_SEQUENCE)",from,to);
         } else if (error && error->code == G_CONVERT_ERROR_FAILED)
         {
-            g_print("Conversion error from '%s' to '%s' (G_CONVERT_ERROR_FAILED)\n",from,to);
+            Log_Print("Conversion error from '%s' to '%s' (G_CONVERT_ERROR_FAILED)",from,to);
         } else if (error && error->code == G_CONVERT_ERROR_PARTIAL_INPUT)
         {
-            g_print("Conversion error from '%s' to '%s' (G_CONVERT_ERROR_PARTIAL_INPUT)\n",from,to);
+            Log_Print("Conversion error from '%s' to '%s' (G_CONVERT_ERROR_PARTIAL_INPUT)",from,to);
         } else if (error && error->code == G_CONVERT_ERROR_BAD_URI)
         {
-            g_print("Conversion error from '%s' to '%s' (G_CONVERT_ERROR_BAD_URI)\n",from,to);
+            Log_Print("Conversion error from '%s' to '%s' (G_CONVERT_ERROR_BAD_URI)",from,to);
         } else if (error && error->code == G_CONVERT_ERROR_NOT_ABSOLUTE_PATH)
         {
-            g_print("Conversion error from '%s' to '%s' (G_CONVERT_ERROR_NOT_ABSOLUTE_PATH)\n",from,to);
+            Log_Print("Conversion error from '%s' to '%s' (G_CONVERT_ERROR_NOT_ABSOLUTE_PATH)",from,to);
         } else
         {
-            g_print("Conversion error from '%s' to '%s' (unknown : %d)\n",from,to,error->code);
+            Log_Print("Conversion error from '%s' to '%s' (unknown : %d)",from,to,error->code);
         }
 
         if (error)
