@@ -118,9 +118,9 @@ typedef enum
     FLAC_FILE,       // FLAC (lossless)           : .flac .fla
     MPC_FILE,        // MusePack                  : .mpc .mp+ .mpp
     MAC_FILE,        // Monkey's Audio (lossless) : .ape            (.mac)
-    //SPEEX_FILE,      // Speech audio files        : .spx
+    SPEEX_FILE,      // Speech audio files        : .spx
     OFR_FILE,        // OptimFROG (lossless)      : .ofr .ofs
-    //WV_FILE,         // Wavpack (lossless)        : .wv
+    WAVPACK_FILE,    // Wavpack (lossless)        : .wv
     UNKNOWN_FILE
 } ET_File_Type;
 
@@ -135,6 +135,7 @@ typedef enum
     APE_TAG,
     FLAC_TAG,
     MP4_TAG,
+    WAVPACK_TAG,
     UNKNOWN_TAG
 } ET_Tag_Type;
 
@@ -148,6 +149,8 @@ struct _File_Name
     guint key;
     gboolean saved;        /* Set to TRUE if this filename had been saved */
     gchar *value;          /* The filename containing the full path and the extension of the file */
+    gchar *value_utf8;     /* Same than "value", but converted to UTF-8 to avoid multiple call to the convertion function */
+    gchar *value_ck;       /* Collate key of "value_utf8" to speed up comparaison */
 };
 
 
@@ -212,7 +215,7 @@ struct _ET_File_Info
     gint size;                  /* The size of file (in bytes) */
     gint duration;              /* The duration of file (in seconds) */
     gchar *mpc_profile;         /* MPC data */
-    gchar *mpc_version;         /* MPC data : encoder version */
+    gchar *mpc_version;         /* MPC data : encoder version  (also for Speex) */
 };
 
 
@@ -240,6 +243,9 @@ static const ET_File_Description ETFileDescription[] =
 #ifdef ENABLE_OGG
     {OGG_FILE,     ".ogg",  OGG_TAG},
 #endif
+#ifdef ENABLE_SPEEX
+    {SPEEX_FILE,   ".spx",  OGG_TAG},  // Implemented by Pierre Dumuid
+#endif
 #ifdef ENABLE_FLAC
     {FLAC_FILE,    ".flac", FLAC_TAG},
     {FLAC_FILE,    ".fla",  FLAC_TAG},
@@ -251,13 +257,14 @@ static const ET_File_Description ETFileDescription[] =
     {MAC_FILE,     ".mac",  APE_TAG},  // Implemented by Artur Polaczynski
     {OFR_FILE,     ".ofr",  APE_TAG},
     {OFR_FILE,     ".ofs",  APE_TAG},
-    //{WV_FILE,      ".wv",   APE_TAG},
 #ifdef ENABLE_MP4
     {MP4_FILE,     ".mp4",  MP4_TAG},  // Implemented by Michael Ihde
     {MP4_FILE,     ".m4a",  MP4_TAG},  // Implemented by Michael Ihde
     {MP4_FILE,     ".m4p",  MP4_TAG},  // Implemented by Michael Ihde
 #endif
-//    {SPEEX_FILE,   ".spx",  OGG_TAG},  // Need to add some particularities...
+#ifdef ENABLE_WAVPACK
+    {WAVPACK_FILE, ".wv",   WAVPACK_TAG}, // Implemented by Maarten Maathuis
+#endif
     {UNKNOWN_FILE, "",      UNKNOWN_TAG}    /* This item must be placed to the end! */
 };
 
@@ -359,16 +366,18 @@ gboolean ET_Check_If_All_Files_Are_Saved (void);
 gboolean ET_Free_History_File_List       (void);
 gboolean ET_Free_Displayed_File_List     (void);
 
-ET_File   *ET_File_Item_New       (void);
-File_Name *ET_File_Name_Item_New  (void);
-File_Tag  *ET_File_Tag_Item_New   (void);
-gboolean   ET_Free_File_Tag_Item  (File_Tag *FileTag);
-gboolean   ET_Free_File_List_Item (ET_File *ETFile);
+ET_File      *ET_File_Item_New       (void);
+File_Name    *ET_File_Name_Item_New  (void);
+File_Tag     *ET_File_Tag_Item_New   (void);
+ET_File_Info *ET_File_Info_Item_New  (void);
+gboolean      ET_Free_File_Tag_Item  (File_Tag *FileTag);
+gboolean      ET_Free_File_List_Item (ET_File *ETFile);
 
-gboolean ET_Copy_File_Tag_Item         (ET_File *ETFile, File_Tag *FileTag);
-gboolean ET_Set_Field_File_Name_Item   (gchar **FileNameField, gchar *value);
-gboolean ET_Set_Field_File_Tag_Item    (gchar **FileTagField,  gchar *value);
-gboolean ET_Set_Field_File_Tag_Picture (gchar **FileTagField, Picture *pic);
+gboolean ET_Copy_File_Tag_Item          (ET_File *ETFile, File_Tag *FileTag);
+gboolean ET_Set_Field_File_Name_Item    (gchar **FileNameField, gchar *value);
+gboolean ET_Set_Filename_File_Name_Item (File_Name *FileName, gchar *filename_utf8, gchar *filename);
+gboolean ET_Set_Field_File_Tag_Item     (gchar **FileTagField,  gchar *value);
+gboolean ET_Set_Field_File_Tag_Picture  (Picture **FileTagField, Picture *pic);
 
 GList   *ET_Displayed_File_List_First       (void);
 GList   *ET_Displayed_File_List_Previous    (void);
