@@ -37,6 +37,7 @@
 #include "vcedit.h"
 #include "et_core.h"
 #include "id3_tag.h"
+#include "log.h"
 #include "misc.h"
 #include "setting.h"
 #include "picture.h"
@@ -49,6 +50,16 @@
 
 #define MULTIFIELD_SEPARATOR " - "
 
+/* Patch from Josh Coalson
+ * FLAC 1.1.3 has FLAC_API_VERSION_CURRENT == 8 *
+ * by LEGACY_FLAC we mean pre-FLAC 1.1.3; in FLAC 1.1.3 the FLAC__FileDecoder was merged into the FLAC__StreamDecoder */
+#if !defined(FLAC_API_VERSION_CURRENT) || FLAC_API_VERSION_CURRENT < 8
+#define LEGACY_FLAC // For FLAC version < 1.1.3
+#else
+#undef LEGACY_FLAC
+#endif
+
+
 /* FLAC uses Ogg Vorbis comments
  * Ogg Vorbis fields names :
  *  - TITLE        : Track name
@@ -59,6 +70,7 @@
  *  - ARTIST       : Track performer
  *  - ORGANIZATION : Name of the organization producing the track (i.e. the 'record label')
  *  - DESCRIPTION  : A short text description of the contents
+ *  - COMME?T      : same than DESCRIPTION
  *  - GENRE        : A short text indication of music genre
  *  - DATE         : Date the track was recorded
  *  - LOCATION     : Location where track was recorded
@@ -125,7 +137,7 @@ gboolean Flac_Tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
             FLAC__metadata_simple_iterator_delete(iter);
         }
 
-        g_print(_("ERROR while opening file: '%s' as FLAC (%s).\n\a"),filename_utf8,flac_error_msg);
+        Log_Print(_("ERROR while opening file: '%s' as FLAC (%s)."),filename_utf8,flac_error_msg);
         g_free(filename_utf8);
         return FALSE;
     }
@@ -166,6 +178,7 @@ gboolean Flac_Tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
         /* Extract field value */
         field = &vc->comments[field_num++];
         field_value = memchr(field->entry, '=', field->length);
+
         if (field_value)
         {
             field_value++;
@@ -388,8 +401,28 @@ gboolean Flac_Tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
      * Comment *
      ***********/
     field_num = 0;
-    while ( (field_num = FLAC__metadata_object_vorbiscomment_find_entry_from(vc_block,field_num,"DESCRIPTION")) >= 0 )
+    while ( 1 )
     {
+        gint field_num1, field_num2;
+
+        // The comment field can take two forms...
+        field_num1 = FLAC__metadata_object_vorbiscomment_find_entry_from(vc_block,field_num,"DESCRIPTION");
+        field_num2 = FLAC__metadata_object_vorbiscomment_find_entry_from(vc_block,field_num,"COMMENT");
+
+        if (field_num1 >= 0 && field_num2 >= 0)
+            // Note : We set field_num to the last "comment" field to avoid to concatenate 
+            // the DESCRIPTION and COMMENT field if there are both present (EasyTAG writes the both...)
+            if (field_num1 < field_num2)
+                field_num = field_num2;
+            else
+                field_num = field_num1;
+        else if (field_num1 >= 0)
+            field_num = field_num1;
+        else if (field_num2 >= 0)
+            field_num = field_num2;
+        else
+            break;
+
         /* Extract field value */
         field = &vc->comments[field_num++];
         field_value = memchr(field->entry, '=', field->length);
@@ -553,6 +586,15 @@ gboolean Flac_Tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
     }
 
 
+    /***********
+     * Picture *
+     ***********/
+    // For FLAC > 1.1.3
+    #ifndef LEGACY_FLAC
+    
+    #endif
+
+
     /***************************
      * Save unsupported fields *
      ***************************/
@@ -568,6 +610,7 @@ gboolean Flac_Tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
           && strncasecmp((gchar *)field->entry,"TRACKTOTAL=",  MIN(11, field->length)) != 0
           && strncasecmp((gchar *)field->entry,"GENRE=",       MIN(6,  field->length)) != 0
           && strncasecmp((gchar *)field->entry,"DESCRIPTION=", MIN(12, field->length)) != 0
+          && strncasecmp((gchar *)field->entry,"COMMENT=",     MIN(8,  field->length)) != 0
           && strncasecmp((gchar *)field->entry,"COMPOSER=",    MIN(9,  field->length)) != 0
           && strncasecmp((gchar *)field->entry,"PERFORMER=",   MIN(10, field->length)) != 0
           && strncasecmp((gchar *)field->entry,"COPYRIGHT=",   MIN(10, field->length)) != 0
@@ -575,7 +618,7 @@ gboolean Flac_Tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
           && strncasecmp((gchar *)field->entry,"ENCODED-BY=",  MIN(11, field->length)) != 0 )
         {
             //g_print("custom %*s\n", field->length, field->entry);
-            FileTag->other = g_list_append(FileTag->other,g_strndup(field->entry, field->length));
+            FileTag->other = g_list_append(FileTag->other,g_strndup((const gchar *)field->entry, field->length));
         }
     }
 
@@ -671,9 +714,9 @@ gboolean Flac_Tag_Write_File_Tag (ET_File *ETFile)
     if (!ETFile || !ETFile->FileTag)
         return FALSE;
 
-    FileTag  = (File_Tag *)ETFile->FileTag->data;
-    filename = ((File_Name *)ETFile->FileNameCur->data)->value;
-    filename_utf8 = filename_to_display(filename);
+    FileTag       = (File_Tag *)ETFile->FileTag->data;
+    filename      = ((File_Name *)ETFile->FileNameCur->data)->value;
+    filename_utf8 = ((File_Name *)ETFile->FileNameCur->data)->value_utf8;
     flac_error_msg = NULL;
 
     /* libFLAC is able to detect (and skip) ID3v2 tags by itself */
@@ -695,8 +738,7 @@ gboolean Flac_Tag_Write_File_Tag (ET_File *ETFile)
             FLAC__metadata_simple_iterator_delete(iter);
         }
 
-        g_print(_("ERROR while opening file: '%s' as FLAC (%s).\n\a"),filename_utf8,flac_error_msg);
-        g_free(filename_utf8);
+        Log_Print(_("ERROR while opening file: '%s' as FLAC (%s)."),filename_utf8,flac_error_msg);
         return FALSE;
     }
 
@@ -830,6 +872,12 @@ gboolean Flac_Tag_Write_File_Tag (ET_File *ETFile)
         field.length = strlen(string);
         FLAC__metadata_object_vorbiscomment_insert_comment(vc_block,vc_block->data.vorbis_comment.num_comments,field,true);
         g_free(string);
+
+        string = g_strconcat("COMMENT=",FileTag->comment,NULL);
+        field.entry = (FLAC__byte *)string;
+        field.length = strlen(string);
+        FLAC__metadata_object_vorbiscomment_insert_comment(vc_block,vc_block->data.vorbis_comment.num_comments,field,true);
+        g_free(string);
     }
 
     /************
@@ -932,15 +980,14 @@ gboolean Flac_Tag_Write_File_Tag (ET_File *ETFile)
     if ( !write_ok )
     {
         flac_error_msg = FLAC__Metadata_SimpleIteratorStatusString[FLAC__metadata_simple_iterator_status(iter)];
-        g_print(_("ERROR: Failed to write comments to file '%s' (%s).\n"),filename_utf8,flac_error_msg);
+        Log_Print(_("ERROR: Failed to write comments to file '%s' (%s)."),filename_utf8,flac_error_msg);
         FLAC__metadata_simple_iterator_delete(iter);
         FLAC__metadata_object_delete(vc_block);
-        g_free(filename_utf8);
         return FALSE;
     }else
     {
         basename_utf8 = g_path_get_basename(filename_utf8);
-        g_print(_("Written tag of '%s'\n"),basename_utf8);
+        Log_Print(_("Written tag of '%s'"),basename_utf8);
         g_free(basename_utf8);
     }
 
@@ -963,7 +1010,8 @@ gboolean Flac_Tag_Write_File_Tag (ET_File *ETFile)
         File_Name *FileName_tmp  = ET_File_Name_Item_New();
         File_Tag  *FileTag_tmp   = ET_File_Tag_Item_New();
         // Same file...
-        FileName_tmp->value      = g_strdup(filename_utf8);
+        FileName_tmp->value      = g_strdup(filename);
+        FileName_tmp->value_utf8 = g_strdup(filename_utf8); // Not necessary to fill 'value_ck'
         ETFile_tmp->FileNameList = g_list_append(NULL,FileName_tmp);
         ETFile_tmp->FileNameCur  = ETFile_tmp->FileNameList;
         // With empty tag...
@@ -974,7 +1022,6 @@ gboolean Flac_Tag_Write_File_Tag (ET_File *ETFile)
     }
 #endif
 
-    g_free(filename_utf8);
     return TRUE;
 }
 
