@@ -87,10 +87,6 @@ void Destroy_Mouse_Cursor (void);
 void Set_Busy_Cursor      (void);
 void Set_Unbusy_Cursor    (void);
 
-// Tooltips
-GtkTooltips *gtk_tooltips_new_1 (void);
-void Set_Tips_Color (GtkTooltips *tips);
-
 // Run Audio Player
 void Run_Audio_Player_Using_File_List (GList *etfilelist);
 void Run_Audio_Player_Using_Directory (void);
