@@ -28,10 +28,13 @@
 #include <stdio.h>
 #include <errno.h>
 #include <unistd.h>
+#include <string.h>
+#include <stdlib.h>
 
 #include "mp4_header.h"
 #include "easytag.h"
 #include "et_core.h"
+#include "log.h"
 #include "misc.h"
 #include "charset.h"
 
@@ -204,8 +207,8 @@ gboolean Mp4_Header_Read_File_Info (gchar *filename, ET_File_Info *ETFileInfo)
     if ((file = MP4Read(filename, 0)) == MP4_INVALID_FILE_HANDLE )
     {
         gchar *filename_utf8 = filename_to_display(filename);
-        //g_print(_("ERROR while opening file: '%s' (%s).\n\a"),filename_utf8,g_strerror(errno));
-        g_print(_("ERROR while opening file: '%s' (%s).\n\a"),filename_utf8,_("MP4 format invalid"));
+        //g_print(_("ERROR while opening file: '%s' (%s)."),filename_utf8,g_strerror(errno));
+        Log_Print(_("ERROR while opening file: '%s' (%s)."),filename_utf8,_("MP4 format invalid"));
         g_free(filename_utf8);
         return FALSE;
     }
@@ -214,7 +217,7 @@ gboolean Mp4_Header_Read_File_Info (gchar *filename, ET_File_Info *ETFileInfo)
     if( MP4GetNumberOfTracks(file,MP4_AUDIO_TRACK_TYPE,0) < 1 )
     {
         gchar *filename_utf8 = filename_to_display(filename);
-        g_print(_("ERROR while opening file: '%s' (%s).\n\a"),filename_utf8,("Contains no audio track"));
+        Log_Print(_("ERROR while opening file: '%s' (%s)."),filename_utf8,("Contains no audio track"));
         MP4Close(file);
         g_free(filename_utf8);
         return FALSE;
