@@ -91,7 +91,7 @@ gboolean Mp4tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
     if ( (file=fopen(filename,"r"))==NULL )
     {
         gchar *filename_utf8 = filename_to_display(filename);
-        Log_Print(_("ERROR while opening file: '%s' (%s).\a"),filename_utf8,g_strerror(errno));
+        Log_Print(_("ERROR while opening file: '%s' (%s)."),filename_utf8,g_strerror(errno));
         g_free(filename_utf8);
         return FALSE;
     }
@@ -102,7 +102,7 @@ gboolean Mp4tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
     if (mp4file == MP4_INVALID_FILE_HANDLE)
     {
         gchar *filename_utf8 = filename_to_display(filename);
-        Log_Print(_("ERROR while opening file: '%s' (%s).\a"),filename_utf8,_("MP4 format invalid"));
+        Log_Print(_("ERROR while opening file: '%s' (%s)."),filename_utf8,_("MP4 format invalid"));
         g_free(filename_utf8);
         return FALSE;
     }
@@ -231,7 +231,7 @@ gboolean Mp4tag_Write_File_Tag (ET_File *ETFile)
     /* Test to know if we can write into the file */
     if ( (file=fopen(filename,"r+"))==NULL )
     {
-        Log_Print(_("ERROR while opening file: '%s' (%s).\a"),filename_utf8,g_strerror(errno));
+        Log_Print(_("ERROR while opening file: '%s' (%s)."),filename_utf8,g_strerror(errno));
         return FALSE;
     }
     fclose(file);
@@ -240,7 +240,7 @@ gboolean Mp4tag_Write_File_Tag (ET_File *ETFile)
     mp4file = MP4Modify(filename,0,0);
     if (mp4file == MP4_INVALID_FILE_HANDLE)
     {
-        Log_Print(_("ERROR while opening file: '%s' (%s).\a"),filename_utf8,_("MP4 format invalid"));
+        Log_Print(_("ERROR while opening file: '%s' (%s)."),filename_utf8,_("MP4 format invalid"));
         return FALSE;
     }
 
