@@ -29,6 +29,7 @@
 #include "mpeg_header.h"
 #include "easytag.h"
 #include "et_core.h"
+#include "log.h"
 #include "misc.h"
 #include "charset.h"
 
@@ -120,7 +121,8 @@ gboolean Mpeg_Header_Read_File_Info (gchar *filename, ET_File_Info *ETFileInfo)
             return FALSE;
         }
 
-        // Skip data of the ID3v2.x tag (It may contain data similar to mpeg frame. In APIC for ex) (patch from Artur Polaczynski)
+        // Skip data of the ID3v2.x tag (It may contain data similar to mpeg frame 
+        // as, for example, in the id3 APIC frame) (patch from Artur Polaczynski)
         if (tmp[0] == 'I' && tmp[1] == 'D' && tmp[2] == '3' && tmp[3] < 0xFF)
         {
             // ID3v2 tag skipeer $49 44 33 yy yy xx zz zz zz zz [zz size]
@@ -204,7 +206,7 @@ gboolean Mpeg_Header_Read_File_Info (gchar *filename, ET_File_Info *ETFileInfo)
     }else
     {
         gchar *filename_utf8 = filename_to_display(filename);
-        g_print(_("ERROR while opening file: '%s' (%s).\n\a"),filename_utf8,g_strerror(errno));
+        Log_Print(_("ERROR while opening file: '%s' (%s)."),filename_utf8,g_strerror(errno));
         g_free(filename_utf8);
         return FALSE;
     }
