@@ -36,13 +36,14 @@
 #include "ogg_tag.h"
 #include "vcedit.h"
 #include "et_core.h"
+#include "log.h"
 #include "misc.h"
 #include "setting.h"
 #include "charset.h"
 
 #ifdef WIN32
 // for mkstemp
-#   include "win32dep.h"
+#   include "win32/win32dep.h"
 #endif
 
 
@@ -135,7 +136,7 @@ gboolean Ogg_Tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
 
     if ( (file=fopen(filename,"rb")) == NULL )
     {
-        g_print(_("ERROR while opening file: '%s' (%s).\n\a"),filename_utf8,g_strerror(errno));
+        Log_Print(_("ERROR while opening file: '%s' (%s)."),filename_utf8,g_strerror(errno));
         g_free(filename_utf8);
         return FALSE;
     }
@@ -159,7 +160,7 @@ gboolean Ogg_Tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
                 id3v2size = 10 + ( (long)(tmp_id3[3])        | ((long)(tmp_id3[2]) << 7)
                                 | ((long)(tmp_id3[1]) << 14) | ((long)(tmp_id3[0]) << 21) );
                 fseek(file, id3v2size, SEEK_SET);
-                g_print(_("Warning : The Ogg Vorbis file '%s' contains an ID3v2 tag.\n"),filename_utf8);
+                Log_Print(_("Warning : The Ogg Vorbis file '%s' contains an ID3v2 tag."),filename_utf8);
             }else
             {
                 fseek(file, 0L, SEEK_SET);
@@ -177,17 +178,22 @@ gboolean Ogg_Tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
     state = vcedit_new_state();    // Allocate memory for 'state'
     if ( vcedit_open(state,file) < 0 )
     {
-        g_print(_("ERROR: Failed to open file: '%s' as vorbis (%s).\n"),filename_utf8,vcedit_error(state));
+        Log_Print(_("ERROR: Failed to open file: '%s' as vorbis (%s)."),filename_utf8,vcedit_error(state));
         ogg_error_msg = vcedit_error(state);
         fclose(file);
         g_free(filename_utf8);
+        vcedit_clear(state);
         return FALSE;
     }
 
 
     /* Get data from tag */
     vc = vcedit_comments(state);
-    //{gint i; for (i=0;i<vc->comments;i++) g_print("%s -> Ogg vc:'%s'\n",g_path_get_basename(filename),vc->user_comments[i]);}
+    /*{
+        gint i; 
+        for (i=0;i<vc->comments;i++) 
+            g_print("%s -> Ogg vc:'%s'\n",g_path_get_basename(filename),vc->user_comments[i]);
+    }*/
 
     /*********
      * Title *
@@ -336,6 +342,7 @@ gboolean Ogg_Tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
                 FileTag->comment = g_strdup(string2);
             else
                 FileTag->comment = g_strconcat(FileTag->comment,MULTIFIELD_SEPARATOR,string2,NULL);
+
             // Frees allocated data
             if (string && g_utf8_strlen(string, -1) > 0)
                 g_free(string);
@@ -347,6 +354,7 @@ gboolean Ogg_Tag_Read_File_Tag (gchar *filename, File_Tag *FileTag)
                 FileTag->comment = g_strdup(string);
             else
                 FileTag->comment = g_strconcat(FileTag->comment,MULTIFIELD_SEPARATOR,string,NULL);
+
             // Frees allocated data
             if (string1 && g_utf8_strlen(string1, -1) > 0)
                 g_free(string1);
@@ -516,14 +524,13 @@ gboolean Ogg_Tag_Write_File_Tag (ET_File *ETFile)
 
     FileTag       = (File_Tag *)ETFile->FileTag->data;
     filename      = ((File_Name *)ETFile->FileNameCur->data)->value;
-    filename_utf8 = filename_to_display(filename);
+    filename_utf8 = ((File_Name *)ETFile->FileNameCur->data)->value_utf8;
     ogg_error_msg = NULL;
 
     /* Test to know if we can write into the file */
     if ( (file_in=fopen(filename,"rb"))==NULL )
     {
-        g_print(_("ERROR while opening file: '%s' (%s).\n\a"),filename_utf8,g_strerror(errno));
-        g_free(filename_utf8);
+        Log_Print(_("ERROR while opening file: '%s' (%s)."),filename_utf8,g_strerror(errno));
         return FALSE;
     }
 
@@ -563,10 +570,10 @@ gboolean Ogg_Tag_Write_File_Tag (ET_File *ETFile)
     state = vcedit_new_state();    // Allocate memory for 'state'
     if ( vcedit_open(state,file_in) < 0 )
     {
-        g_print(_("ERROR: Failed to open file: '%s' as vorbis (%s).\n"),filename_utf8,vcedit_error(state));
+        Log_Print(_("ERROR: Failed to open file: '%s' as vorbis (%s)."),filename_utf8,vcedit_error(state));
         ogg_error_msg = vcedit_error(state);
         fclose(file_in);
-        g_free(filename_utf8);
+        vcedit_clear(state);
         return FALSE;
     }
 
@@ -738,85 +745,89 @@ gboolean Ogg_Tag_Write_File_Tag (ET_File *ETFile)
         list = list->next;
     }
 
-
-    /* Write tag */
+    /* Write tag, and close also 'file_in' in all cases */
     if ( Ogg_Tag_Write_File(file_in,filename,state) == FALSE )
     {
         ogg_error_msg = vcedit_error(state);
-        g_print(_("ERROR: Failed to write comments to file '%s' (%s).\n"),filename_utf8,ogg_error_msg == NULL ? "" : ogg_error_msg);
-        g_free(filename_utf8);
+        Log_Print(_("ERROR: Failed to write comments to file '%s' (%s)."),filename_utf8,ogg_error_msg == NULL ? "" : ogg_error_msg);
+
+        vcedit_clear(state);
         return FALSE;
     }else
     {
         basename_utf8 = g_path_get_basename(filename_utf8);
-        g_print(_("Written tag of '%s'\n"),basename_utf8);
-        g_free(basename_utf8);
-    }
+        Log_Print(_("Written tag of '%s'"),basename_utf8);
 
-    vcedit_clear(state);
-    g_free(filename_utf8);
+        vcedit_clear(state);
+    }
 
     return TRUE;
 }
 
 
 
-/* This function is based on work of :
- *  XMMS - Cross-platform multimedia player
- *  Copyright (C) 1998-2001  Peter Alm, Mikael Alm, Olle Hallnas, Thomas Nilsson and 4Front Technologies
- *  Copyright (C) 1999-2001  Hvard Kvlen
- *  Copyright (C) 2001, Jorn Baayen <jorn@nl.linux.org>
+/* 
+ * Write tag informations to a new temporary file, and rename it the the initial name.
  */
 gboolean Ogg_Tag_Write_File (FILE *file_in, gchar *filename_in, vcedit_state *state)
 {
-    gchar *filename_tmp;
+    gchar *filename_out;
     gint   file_mkstemp;
     FILE  *file_out;
     gboolean return_code = TRUE;
 
-    filename_tmp = g_strdup_printf("%s.XXXXXX",filename_in);
 
-    if ((file_mkstemp = mkstemp(filename_tmp)) < 0)
+    filename_out = g_strdup_printf("%s.XXXXXX",filename_in);
+    
+    // Function mkstemp() opens also the file!
+    if ((file_mkstemp = mkstemp(filename_out)) < 0)
     {
-        g_free(filename_tmp);
         fclose(file_in);
-        return FALSE;
-    }
-
-    if ( (file_out=fdopen(file_mkstemp,"wb")) == NULL )
-    {
         close(file_mkstemp);
-        remove(filename_tmp);
-        g_free(filename_tmp);
-
-        fclose(file_in);
+        g_free(filename_out);
         return FALSE;
     }
-
-    if (vcedit_write(state,file_out) < 0)
-        return_code = FALSE;
-
-    fclose(file_in);
-
-    if (fclose(file_out) != 0)
-        return_code = FALSE;
-
-    // TIX ME : Part commented as the ogg file will be corrupted later...
-//#ifdef WIN32
-//    // Under Win32, rename(a,b) fails if b exists...
-//    if(return_code == TRUE)
-//    {
-//        remove(filename_in);
-//    }
-//#endif
-
-    if ( (return_code==FALSE) || (rename(filename_tmp,filename_in)<0) )
+    close(file_mkstemp);
+    
+    if ( (file_out=fopen(filename_out,"wb")) == NULL )
     {
-        remove(filename_tmp);
-        return_code = FALSE;
+        fclose(file_in);
+        remove(filename_out);
+        g_free(filename_out);
+        return FALSE;
+    }
+    
+    if (vcedit_write(state,file_out) < 0)
+    {
+        fclose(file_in);
+        fclose(file_out);
+        remove(filename_out);
+        g_free(filename_out);
+        return FALSE;
+    }
+    fclose(file_in);
+    fclose(file_out);
+
+    // Some platforms fail to rename a file if the new name already
+    // exists, so we need to remove, then rename...
+    if (rename(filename_out,filename_in))
+    {
+        // Can't rename directly
+        if (remove(filename_in))
+        {
+            // Can't remove file
+            remove(filename_out);
+            return_code = FALSE;
+
+        }else if (rename(filename_out,filename_in)) 
+        {
+            // Can't rename after removing file
+            remove(filename_out);
+            return_code = FALSE;
+        }
     }
 
-    g_free(filename_tmp);
+    g_free(filename_out);
 
     return return_code;
 }
