@@ -307,11 +307,14 @@ void Picture_Add_Button_Clicked (GObject *object)
     // "PNG and JPEG" filter
     filter = gtk_file_filter_new ();
     gtk_file_filter_set_name(GTK_FILE_FILTER(filter), _("PNG and JPEG"));
-    gtk_file_filter_add_mime_type(GTK_FILE_FILTER(filter), "image/jpeg");
-    gtk_file_filter_add_mime_type(GTK_FILE_FILTER(filter), "image/png");
+    //gtk_file_filter_add_mime_type(GTK_FILE_FILTER(filter), "image/jpeg");
+    //gtk_file_filter_add_mime_type(GTK_FILE_FILTER(filter), "image/png");
+    gtk_file_filter_add_pattern(GTK_FILE_FILTER(filter), "*.jpeg");
+    gtk_file_filter_add_pattern(GTK_FILE_FILTER(filter), "*.jpg");
+    gtk_file_filter_add_pattern(GTK_FILE_FILTER(filter), "*.png");
     gtk_file_chooser_add_filter(GTK_FILE_CHOOSER (FileSelectionWindow), GTK_FILE_FILTER(filter));
     // Make this filter the default
-    gtk_file_chooser_set_filter(GTK_FILE_CHOOSER(FileSelectionWindow),  GTK_FILE_FILTER(filter));
+    gtk_file_chooser_set_filter(GTK_FILE_CHOOSER(FileSelectionWindow), GTK_FILE_FILTER(filter));
 
     // Set window position
     if (MESSAGE_BOX_POSITION_NONE)
