@@ -67,30 +67,43 @@ GtkWidget *FilenameExtensionNoChange;
 GtkWidget *FilenameExtensionLowerCase;
 GtkWidget *FilenameExtensionUpperCase;
 GtkWidget *PreserveModificationTime;
+GtkWidget *UpdateParentDirectoryModificationTime;
 
 GtkWidget *FilenameCharacterSetOther;
 GtkWidget *FilenameCharacterSetApproximate;
 GtkWidget *FilenameCharacterSetDiscard;
 
 /* Tag Settings */
-GtkWidget *WriteId3v1Tag;
-GtkWidget *WriteId3v2Tag;
+GtkWidget *FileWritingId3v2WriteTag;
+GtkWidget *FileWritingId3v1WriteTag;
 GtkWidget *WriteId3TagsInFlacFiles;
-GtkWidget *UseId3v2Padding;
+GtkWidget *FileWritingId3v2UseCrc32;
+GtkWidget *FileWritingId3v2UseCompression;
 GtkWidget *StripTagWhenEmptyFields;
 GtkWidget *ConvertOldId3v2TagVersion;
 
-GtkWidget *UseId3ISO88591CharacterSet;
-GtkWidget *UseId3ISO88591ThenUnicodeCharacterSet;
-GtkWidget *UseId3UnicodeCharacterSet;
+GtkWidget *FileWritingId3v2VersionCombo;
+GtkWidget *FileWritingId3v2UnicodeCharacterSetCombo;
+GtkWidget *FileWritingId3v2NoUnicodeCharacterSetCombo;
+GtkWidget *FileWritingId3v1CharacterSetCombo;
+GtkWidget *FileWritingId3v2UseUnicodeCharacterSet;
+GtkWidget *FileWritingId3v2UseNoUnicodeCharacterSet;
 GtkWidget *UseNonStandardId3ReadingCharacterSet;
-GtkWidget *UseNonStandardId3WritingCharacterSet;
-GtkWidget *FileReadingCharacterSetCombo;
-GtkWidget *FileWritingCharacterSetCombo;
+GtkWidget *FileReadingId3v1v2CharacterSetCombo;
 
-GtkWidget *FileWritingCharacterSetOther;
-GtkWidget *FileWritingCharacterSetApproximate;
-GtkWidget *FileWritingCharacterSetDiscard;
+GtkWidget *FileReadingId3v1v2CharacterSetCombo;
+GtkWidget *FileWritingId3v2IconvOptionsNo;
+GtkWidget *FileWritingId3v2IconvOptionsTranslit;
+GtkWidget *FileWritingId3v2IconvOptionsIgnore;
+GtkWidget *FileWritingId3v1IconvOptionsNo;
+GtkWidget *FileWritingId3v1IconvOptionsTranslit;
+GtkWidget *FileWritingId3v1IconvOptionsIgnore;
+
+GtkWidget *LabelAdditionalId3v1IconvOptions;
+GtkWidget *LabelAdditionalId3v2IconvOptions;
+GtkWidget *LabelId3v2Charset;
+GtkWidget *LabelId3v1Charset;
+GtkWidget *LabelId3v2Version;
 
 GtkWidget *DateAutoCompletion;
 GtkWidget *NumberTrackFormated;
@@ -131,6 +144,9 @@ GtkWidget *CddbProxyPort;
 GtkWidget *CddbProxyUserName;
 GtkWidget *CddbProxyUserPassword;
 
+GtkWidget *CddbLocalPath;
+GtkListStore *CddbLocalPathModel;
+
 GtkWidget *SetCddbWindowSize;
 GtkWidget *CddbWindowWidth;
 GtkWidget *CddbWindowHeight;
