@@ -38,12 +38,13 @@
 #include "easytag.h"
 #include "charset.h"
 #include "scan.h"
+#include "log.h"
 #include "misc.h"
 #include "cddb.h"
 #include "browser.h"
 
 #ifdef WIN32
-#   include "win32dep.h"
+#   include "win32/win32dep.h"
 #endif
 
 
@@ -91,6 +92,9 @@ gchar *FILE_TO_LOAD_HISTORY_FILE                   = ".easytag/file_to_load.hist
 gchar *CDDB_SEARCH_STRING_HISTORY_FILE             = ".easytag/cddb_search_string.history";
 // File for history of CddbSearchStringInResultEntry combobox
 gchar *CDDB_SEARCH_STRING_IN_RESULT_HISTORY_FILE   = ".easytag/cddb_search_string_in_result.history";
+// File for history of CddbLocalPath combobox
+gchar *CDDB_LOCAL_PATH_HISTORY_FILE                = ".easytag/cddb_local_path.history";
+
 
 
 
@@ -121,6 +125,7 @@ tConfigVariable Config_Variables[] =
     {"pane_handle_position1",               CV_TYPE_INT,     &PANE_HANDLE_POSITION1             },
     {"pane_handle_position2",               CV_TYPE_INT,     &PANE_HANDLE_POSITION2             },
     {"pane_handle_position3",               CV_TYPE_INT,     &PANE_HANDLE_POSITION3             },
+    {"pane_handle_position4",               CV_TYPE_INT,     &PANE_HANDLE_POSITION4             },
     {"show_header_infos",                   CV_TYPE_BOOL,    &SHOW_HEADER_INFO                  },
     {"changed_files_displayed_to_red",      CV_TYPE_BOOL,    &CHANGED_FILES_DISPLAYED_TO_RED    },
     {"changed_files_displayed_to_bold",     CV_TYPE_BOOL,    &CHANGED_FILES_DISPLAYED_TO_BOLD   },
@@ -134,31 +139,36 @@ tConfigVariable Config_Variables[] =
     {"sorting_file_mode",                    CV_TYPE_INT,     &SORTING_FILE_MODE                        },
     {"sorting_file_case_sensitive",          CV_TYPE_BOOL,    &SORTING_FILE_CASE_SENSITIVE              },
 
-    {"replace_illegal_character_in_filename",CV_TYPE_BOOL,    &REPLACE_ILLEGAL_CHARACTERS_IN_FILENAME   },
-    {"filename_extension_lower_case",        CV_TYPE_BOOL,    &FILENAME_EXTENSION_LOWER_CASE            },
-    {"filename_extension_upper_case",        CV_TYPE_BOOL,    &FILENAME_EXTENSION_UPPER_CASE            },
-    {"filename_extension_no_change",         CV_TYPE_BOOL,    &FILENAME_EXTENSION_NO_CHANGE             },
-    {"preserve_modification_time",           CV_TYPE_BOOL,    &PRESERVE_MODIFICATION_TIME               },
-    {"filename_character_set_other",         CV_TYPE_BOOL,    &FILENAME_CHARACTER_SET_OTHER             },
-    {"filename_character_set_approximate",   CV_TYPE_BOOL,    &FILENAME_CHARACTER_SET_APPROXIMATE       },
-    {"filename_character_set_discard",       CV_TYPE_BOOL,    &FILENAME_CHARACTER_SET_DISCARD           },
+    {"replace_illegal_character_in_filename",          CV_TYPE_BOOL,    &REPLACE_ILLEGAL_CHARACTERS_IN_FILENAME   },
+    {"filename_extension_lower_case",                  CV_TYPE_BOOL,    &FILENAME_EXTENSION_LOWER_CASE            },
+    {"filename_extension_upper_case",                  CV_TYPE_BOOL,    &FILENAME_EXTENSION_UPPER_CASE            },
+    {"filename_extension_no_change",                   CV_TYPE_BOOL,    &FILENAME_EXTENSION_NO_CHANGE             },
+    {"preserve_modification_time",                     CV_TYPE_BOOL,    &PRESERVE_MODIFICATION_TIME               },
+    {"update_parent_directory_modification_time",      CV_TYPE_BOOL,    &UPDATE_PARENT_DIRECTORY_MODIFICATION_TIME},
+    {"filename_character_set_other",                   CV_TYPE_BOOL,    &FILENAME_CHARACTER_SET_OTHER             },
+    {"filename_character_set_approximate",             CV_TYPE_BOOL,    &FILENAME_CHARACTER_SET_APPROXIMATE       },
+    {"filename_character_set_discard",                 CV_TYPE_BOOL,    &FILENAME_CHARACTER_SET_DISCARD           },
 
-    {"write_id3v1_tag",                                 CV_TYPE_BOOL,  &WRITE_ID3V1_TAG                                 },
-    {"write_id3v2_tag",                                 CV_TYPE_BOOL,  &WRITE_ID3V2_TAG                                 },
-    {"write_id3_tags_in_flac_file",                     CV_TYPE_BOOL,  &WRITE_ID3_TAGS_IN_FLAC_FILE                     },
-    {"use_id3v2_padding",                               CV_TYPE_BOOL,  &USE_ID3V2_PADDING                               },
-    {"strip_tag_when_empty_fields",                     CV_TYPE_BOOL,  &STRIP_TAG_WHEN_EMPTY_FIELDS                     },
-    {"convert_old_id3v2_tag_version",                   CV_TYPE_BOOL,  &CONVERT_OLD_ID3V2_TAG_VERSION                   },
-    {"use_id3_iso_8859_1_character_set",                CV_TYPE_BOOL,  &USE_ID3_ISO_8859_1_CHARACTER_SET                },
-    {"use_id3_iso_8859_1_then_unicode_character_set",   CV_TYPE_BOOL,  &USE_ID3_ISO_8859_1_THEN_UNICODE_CHARACTER_SET   },
-    {"use_id3_unicode_character_set",                   CV_TYPE_BOOL,  &USE_ID3_UNICODE_CHARACTER_SET                   },
-    {"use_non_standard_id3_reading_character_set",      CV_TYPE_BOOL,  &USE_NON_STANDARD_ID3_READING_CHARACTER_SET      },
-    {"use_non_standard_id3_writing_character_set",      CV_TYPE_BOOL,  &USE_NON_STANDARD_ID3_WRITING_CHARACTER_SET      },
-    {"id3_file_reading_character_set",                  CV_TYPE_STRING,&ID3_FILE_READING_CHARACTER_SET                  },
-    {"id3_file_writing_character_set",                  CV_TYPE_STRING,&ID3_FILE_WRITING_CHARACTER_SET                  },
-    {"file_writing_character_set_other",                CV_TYPE_BOOL,  &FILE_WRITING_CHARACTER_SET_OTHER                },
-    {"file_writing_character_set_approximate",          CV_TYPE_BOOL,  &FILE_WRITING_CHARACTER_SET_APPROXIMATE          },
-    {"file_writing_character_set_discard",              CV_TYPE_BOOL,  &FILE_WRITING_CHARACTER_SET_DISCARD              },
+    {"write_id3_tags_in_flac_file",                    CV_TYPE_BOOL,  &WRITE_ID3_TAGS_IN_FLAC_FILE                     },
+    {"strip_tag_when_empty_fields",                    CV_TYPE_BOOL,  &STRIP_TAG_WHEN_EMPTY_FIELDS                     },
+    {"convert_old_id3v2_tag_version",                  CV_TYPE_BOOL,  &CONVERT_OLD_ID3V2_TAG_VERSION                   },
+    {"use_non_standard_id3_reading_character_set",     CV_TYPE_BOOL,  &USE_NON_STANDARD_ID3_READING_CHARACTER_SET},
+    {"file_reading_id3v1v2_character_set",             CV_TYPE_STRING,&FILE_READING_ID3V1V2_CHARACTER_SET},
+    {"file_writing_id3v2_write_tag",                   CV_TYPE_BOOL,  &FILE_WRITING_ID3V2_WRITE_TAG    },
+    {"file_writing_id3v2_version_4",                   CV_TYPE_BOOL,  &FILE_WRITING_ID3V2_VERSION_4   },
+    {"file_writing_id3v2_use_crc32",                   CV_TYPE_BOOL,  &FILE_WRITING_ID3V2_USE_CRC32    },
+    {"file_writing_id3v2_use_compression",             CV_TYPE_BOOL,  &FILE_WRITING_ID3V2_USE_COMPRESSION    },
+    {"file_writing_id3v2_use_unicode_character_set",   CV_TYPE_BOOL,  &FILE_WRITING_ID3V2_USE_UNICODE_CHARACTER_SET},
+    {"file_writing_id3v2_unicode_character_set",       CV_TYPE_STRING,&FILE_WRITING_ID3V2_UNICODE_CHARACTER_SET},
+    {"file_writing_id3v2_no_unicode_character_set",    CV_TYPE_STRING,&FILE_WRITING_ID3V2_NO_UNICODE_CHARACTER_SET},
+    {"file_writing_id3v2_iconv_options_no",            CV_TYPE_BOOL,  &FILE_WRITING_ID3V2_ICONV_OPTIONS_NO},
+    {"file_writing_id3v2_iconv_options_translit",      CV_TYPE_BOOL,  &FILE_WRITING_ID3V2_ICONV_OPTIONS_TRANSLIT},
+    {"file_writing_id3v2_iconv_options_ignore",        CV_TYPE_BOOL,  &FILE_WRITING_ID3V2_ICONV_OPTIONS_IGNORE},
+    {"file_writing_id3v1_write_tag",                   CV_TYPE_BOOL,  &FILE_WRITING_ID3V1_WRITE_TAG   },
+    {"file_writing_id3v1_character_set",               CV_TYPE_STRING,&FILE_WRITING_ID3V1_CHARACTER_SET},
+    {"file_writing_id3v1_iconv_options_no",            CV_TYPE_BOOL,  &FILE_WRITING_ID3V1_ICONV_OPTIONS_NO},
+    {"file_writing_id3v1_iconv_options_translit",      CV_TYPE_BOOL,  &FILE_WRITING_ID3V1_ICONV_OPTIONS_TRANSLIT},
+    {"file_writing_id3v1_iconv_options_ignore",        CV_TYPE_BOOL,  &FILE_WRITING_ID3V1_ICONV_OPTIONS_IGNORE},
 
     {"message_box_position_none",               CV_TYPE_BOOL,  &MESSAGE_BOX_POSITION_NONE                },
     {"message_box_position_center",             CV_TYPE_BOOL,  &MESSAGE_BOX_POSITION_CENTER              },
@@ -225,8 +235,16 @@ tConfigVariable Config_Variables[] =
     {"playlist_content_filename",               CV_TYPE_BOOL,    &PLAYLIST_CONTENT_FILENAME              },
     {"playlist_content_mask",                   CV_TYPE_BOOL,    &PLAYLIST_CONTENT_MASK                  },
     {"playlist_content_mask_value",             CV_TYPE_STRING,  &PLAYLIST_CONTENT_MASK_VALUE            },
+    {"playlist_window_x",                       CV_TYPE_INT,     &PLAYLIST_WINDOW_X                      },
+    {"playlist_window_y",                       CV_TYPE_INT,     &PLAYLIST_WINDOW_Y                      },
+    {"playlist_window_width",                   CV_TYPE_INT,     &PLAYLIST_WINDOW_WIDTH                  },
+    {"playlist_window_height",                  CV_TYPE_INT,     &PLAYLIST_WINDOW_HEIGHT                 },
 
     {"load_file_run_scanner",                   CV_TYPE_BOOL,    &LOAD_FILE_RUN_SCANNER                  },
+    {"load_file_window_x",                      CV_TYPE_INT,     &LOAD_FILE_WINDOW_X                     },
+    {"load_file_window_y",                      CV_TYPE_INT,     &LOAD_FILE_WINDOW_Y                     },
+    {"load_file_window_width",                  CV_TYPE_INT,     &LOAD_FILE_WINDOW_WIDTH                 },
+    {"load_file_window_height",                 CV_TYPE_INT,     &LOAD_FILE_WINDOW_HEIGHT                },
 
     {"cddb_server_name_automatic_search",       CV_TYPE_STRING,  &CDDB_SERVER_NAME_AUTOMATIC_SEARCH      },
     {"cddb_server_port_automatic_search",       CV_TYPE_INT,     &CDDB_SERVER_PORT_AUTOMATIC_SEARCH      },
@@ -237,6 +255,7 @@ tConfigVariable Config_Variables[] =
     {"cddb_server_name_manual_search",          CV_TYPE_STRING,  &CDDB_SERVER_NAME_MANUAL_SEARCH         },
     {"cddb_server_port_manual_search",          CV_TYPE_INT,     &CDDB_SERVER_PORT_MANUAL_SEARCH         },
     {"cddb_server_cgi_path_manual_search",      CV_TYPE_STRING,  &CDDB_SERVER_CGI_PATH_MANUAL_SEARCH     },
+    {"cddb_local_path",                         CV_TYPE_STRING,  &CDDB_LOCAL_PATH                        },
     {"cddb_use_proxy",                          CV_TYPE_INT,     &CDDB_USE_PROXY                         },
     {"cddb_proxy_name",                         CV_TYPE_STRING,  &CDDB_PROXY_NAME                        },
     {"cddb_proxy_port",                         CV_TYPE_INT,     &CDDB_PROXY_PORT                        },
@@ -251,6 +270,7 @@ tConfigVariable Config_Variables[] =
 
     {"cddb_follow_file",                        CV_TYPE_BOOL,    &CDDB_FOLLOW_FILE                       },
     {"cddb_use_dlm",                            CV_TYPE_BOOL,    &CDDB_USE_DLM                           },
+    {"cddb_use_local_access",                   CV_TYPE_BOOL,    &CDDB_USE_LOCAL_ACCESS                  },
 
     {"cddb_search_in_all_fields",               CV_TYPE_BOOL,    &CDDB_SEARCH_IN_ALL_FIELDS              },
     {"cddb_search_in_artist_field",             CV_TYPE_BOOL,    &CDDB_SEARCH_IN_ARTIST_FIELD            },
@@ -340,6 +360,7 @@ void Init_Config_Variables (void)
     PANE_HANDLE_POSITION1           = 660;
     PANE_HANDLE_POSITION2           = 360;
     PANE_HANDLE_POSITION3           = 300;
+    PANE_HANDLE_POSITION4           = 300;
     SHOW_HEADER_INFO                = 1;
     CHANGED_FILES_DISPLAYED_TO_RED  = 1;
     CHANGED_FILES_DISPLAYED_TO_BOLD = 0;
@@ -376,6 +397,7 @@ void Init_Config_Variables (void)
     FILENAME_EXTENSION_UPPER_CASE               = 0;
     FILENAME_EXTENSION_NO_CHANGE                = 0;
     PRESERVE_MODIFICATION_TIME                  = 1;
+    UPDATE_PARENT_DIRECTORY_MODIFICATION_TIME   = 0;
 
     FILENAME_CHARACTER_SET_OTHER                = 1;
     FILENAME_CHARACTER_SET_APPROXIMATE          = 0;
@@ -384,22 +406,26 @@ void Init_Config_Variables (void)
     /*
      * Tag Settings
      */
-    WRITE_ID3V1_TAG                                 = 1;
-    WRITE_ID3V2_TAG                                 = 1;
     WRITE_ID3_TAGS_IN_FLAC_FILE                     = 0;
-    USE_ID3V2_PADDING                               = 1;
     STRIP_TAG_WHEN_EMPTY_FIELDS                     = 1;
     CONVERT_OLD_ID3V2_TAG_VERSION                   = 1;
-    USE_ID3_ISO_8859_1_CHARACTER_SET                = 0;
-    USE_ID3_ISO_8859_1_THEN_UNICODE_CHARACTER_SET   = 1;
-    USE_ID3_UNICODE_CHARACTER_SET                   = 0;
     USE_NON_STANDARD_ID3_READING_CHARACTER_SET      = 0;
-    USE_NON_STANDARD_ID3_WRITING_CHARACTER_SET      = 0;
-    ID3_FILE_READING_CHARACTER_SET                  = g_strdup("UTF-8");
-    ID3_FILE_WRITING_CHARACTER_SET                  = g_strdup("ISO-8859-15");
-    FILE_WRITING_CHARACTER_SET_OTHER                = 0;
-    FILE_WRITING_CHARACTER_SET_APPROXIMATE          = 1;
-    FILE_WRITING_CHARACTER_SET_DISCARD              = 0;
+    FILE_READING_ID3V1V2_CHARACTER_SET              = g_strdup("UTF-8");
+    FILE_WRITING_ID3V2_WRITE_TAG                    = 1;
+    FILE_WRITING_ID3V2_VERSION_4                    = 1;
+    FILE_WRITING_ID3V2_USE_CRC32                    = 0;
+    FILE_WRITING_ID3V2_USE_COMPRESSION              = 0;
+    FILE_WRITING_ID3V2_USE_UNICODE_CHARACTER_SET    = 1;
+    FILE_WRITING_ID3V2_UNICODE_CHARACTER_SET        = g_strdup("UTF-8");
+    FILE_WRITING_ID3V2_NO_UNICODE_CHARACTER_SET     = g_strdup("ISO-8859-1");
+    FILE_WRITING_ID3V2_ICONV_OPTIONS_NO             = 1;
+    FILE_WRITING_ID3V2_ICONV_OPTIONS_TRANSLIT       = 0;
+    FILE_WRITING_ID3V2_ICONV_OPTIONS_IGNORE         = 0;
+    FILE_WRITING_ID3V1_WRITE_TAG                    = 1;
+    FILE_WRITING_ID3V1_CHARACTER_SET                = g_strdup("ISO-8859-1");
+    FILE_WRITING_ID3V1_ICONV_OPTIONS_NO             = 1;
+    FILE_WRITING_ID3V1_ICONV_OPTIONS_TRANSLIT       = 0;
+    FILE_WRITING_ID3V1_ICONV_OPTIONS_IGNORE         = 0;
 
     /*
      * Scanner
@@ -473,10 +499,19 @@ void Init_Config_Variables (void)
     PLAYLIST_CONTENT_MASK           = 0;
     PLAYLIST_CONTENT_MASK_VALUE     = g_strdup("%n/%l - %a - %b - %t");
 
+    PLAYLIST_WINDOW_X               = -1;
+    PLAYLIST_WINDOW_Y               = -1;
+    PLAYLIST_WINDOW_WIDTH           = -1;
+    PLAYLIST_WINDOW_HEIGHT          = -1;
+
     /*
      * Load File window
      */
     LOAD_FILE_RUN_SCANNER     = 0;
+    LOAD_FILE_WINDOW_X        = -1;
+    LOAD_FILE_WINDOW_Y        = -1;
+    LOAD_FILE_WINDOW_WIDTH    = -1;
+    LOAD_FILE_WINDOW_HEIGHT   = -1;
 
     /*
      * CDDB window
@@ -484,12 +519,13 @@ void Init_Config_Variables (void)
     CDDB_SERVER_NAME_AUTOMATIC_SEARCH       = g_strdup("freedb.freedb.org");
     CDDB_SERVER_PORT_AUTOMATIC_SEARCH       = 80;
     CDDB_SERVER_CGI_PATH_AUTOMATIC_SEARCH   = g_strdup("/~cddb/cddb.cgi");
-    CDDB_SERVER_NAME_AUTOMATIC_SEARCH2      = g_strdup("www.mb.inhouse.co.uk");
+    CDDB_SERVER_NAME_AUTOMATIC_SEARCH2      = g_strdup("freedb.musicbrainz.org");
     CDDB_SERVER_PORT_AUTOMATIC_SEARCH2      = 80;
     CDDB_SERVER_CGI_PATH_AUTOMATIC_SEARCH2  = g_strdup("/~cddb/cddb.cgi");
     CDDB_SERVER_NAME_MANUAL_SEARCH          = g_strdup("www.gnudb.org");
     CDDB_SERVER_PORT_MANUAL_SEARCH          = 80;
     CDDB_SERVER_CGI_PATH_MANUAL_SEARCH      = g_strdup("/~cddb/cddb.cgi");
+    CDDB_LOCAL_PATH                         = NULL;
     CDDB_USE_PROXY                          = 0;
     CDDB_PROXY_NAME                         = g_strdup("localhost");
     CDDB_PROXY_PORT                         = 8080;
@@ -505,6 +541,7 @@ void Init_Config_Variables (void)
 
     CDDB_FOLLOW_FILE              = 1;
     CDDB_USE_DLM                  = 0;
+    CDDB_USE_LOCAL_ACCESS         = 0;
 
     CDDB_SEARCH_IN_ALL_FIELDS           = 0;
     CDDB_SEARCH_IN_ARTIST_FIELD         = 1;
@@ -576,6 +613,7 @@ void Init_Config_Variables (void)
 void Apply_Changes_Of_Preferences_Window (void)
 {
     gchar *temp;
+    int active;
 
     if (OptionsWindow)
     {
@@ -617,45 +655,60 @@ void Apply_Changes_Of_Preferences_Window (void)
         MESSAGE_BOX_POSITION_CENTER_ON_PARENT   = GTK_TOGGLE_BUTTON(MessageBoxPositionCenterOnParent)->active;
 
         if (AUDIO_FILE_PLAYER) g_free(AUDIO_FILE_PLAYER);
-        AUDIO_FILE_PLAYER           = g_strdup(gtk_entry_get_text(GTK_ENTRY(GTK_BIN(FilePlayerCombo)->child)));
+        AUDIO_FILE_PLAYER                       = g_strdup(gtk_entry_get_text(GTK_ENTRY(GTK_BIN(FilePlayerCombo)->child)));
 
         /* File Settings */
-        REPLACE_ILLEGAL_CHARACTERS_IN_FILENAME = GTK_TOGGLE_BUTTON(ReplaceIllegalCharactersInFilename)->active;
-        FILENAME_EXTENSION_LOWER_CASE          = GTK_TOGGLE_BUTTON(FilenameExtensionLowerCase)->active;
-        FILENAME_EXTENSION_UPPER_CASE          = GTK_TOGGLE_BUTTON(FilenameExtensionUpperCase)->active;
-        FILENAME_EXTENSION_NO_CHANGE           = GTK_TOGGLE_BUTTON(FilenameExtensionNoChange)->active;
-        PRESERVE_MODIFICATION_TIME             = GTK_TOGGLE_BUTTON(PreserveModificationTime)->active;
+        REPLACE_ILLEGAL_CHARACTERS_IN_FILENAME    = GTK_TOGGLE_BUTTON(ReplaceIllegalCharactersInFilename)->active;
+        FILENAME_EXTENSION_LOWER_CASE             = GTK_TOGGLE_BUTTON(FilenameExtensionLowerCase)->active;
+        FILENAME_EXTENSION_UPPER_CASE             = GTK_TOGGLE_BUTTON(FilenameExtensionUpperCase)->active;
+        FILENAME_EXTENSION_NO_CHANGE              = GTK_TOGGLE_BUTTON(FilenameExtensionNoChange)->active;
+        PRESERVE_MODIFICATION_TIME                = GTK_TOGGLE_BUTTON(PreserveModificationTime)->active;
+        UPDATE_PARENT_DIRECTORY_MODIFICATION_TIME = GTK_TOGGLE_BUTTON(UpdateParentDirectoryModificationTime)->active;
 
-        FILENAME_CHARACTER_SET_OTHER           = GTK_TOGGLE_BUTTON(FilenameCharacterSetOther)->active;
-        FILENAME_CHARACTER_SET_APPROXIMATE     = GTK_TOGGLE_BUTTON(FilenameCharacterSetApproximate)->active;
-        FILENAME_CHARACTER_SET_DISCARD         = GTK_TOGGLE_BUTTON(FilenameCharacterSetDiscard)->active;
+        FILENAME_CHARACTER_SET_OTHER              = GTK_TOGGLE_BUTTON(FilenameCharacterSetOther)->active;
+        FILENAME_CHARACTER_SET_APPROXIMATE        = GTK_TOGGLE_BUTTON(FilenameCharacterSetApproximate)->active;
+        FILENAME_CHARACTER_SET_DISCARD            = GTK_TOGGLE_BUTTON(FilenameCharacterSetDiscard)->active;
 
         /* Tag Settings */
-        WRITE_ID3V1_TAG               = GTK_TOGGLE_BUTTON(WriteId3v1Tag)->active;
-        WRITE_ID3V2_TAG               = GTK_TOGGLE_BUTTON(WriteId3v2Tag)->active;
-        WRITE_ID3_TAGS_IN_FLAC_FILE   = GTK_TOGGLE_BUTTON(WriteId3TagsInFlacFiles)->active;
-        USE_ID3V2_PADDING             = GTK_TOGGLE_BUTTON(UseId3v2Padding)->active;
-        STRIP_TAG_WHEN_EMPTY_FIELDS   = GTK_TOGGLE_BUTTON(StripTagWhenEmptyFields)->active;
-        CONVERT_OLD_ID3V2_TAG_VERSION = GTK_TOGGLE_BUTTON(ConvertOldId3v2TagVersion)->active;
+        WRITE_ID3_TAGS_IN_FLAC_FILE                = GTK_TOGGLE_BUTTON(WriteId3TagsInFlacFiles)->active;
+        STRIP_TAG_WHEN_EMPTY_FIELDS                = GTK_TOGGLE_BUTTON(StripTagWhenEmptyFields)->active;
+        CONVERT_OLD_ID3V2_TAG_VERSION              = GTK_TOGGLE_BUTTON(ConvertOldId3v2TagVersion)->active;
+        USE_NON_STANDARD_ID3_READING_CHARACTER_SET = GTK_TOGGLE_BUTTON(UseNonStandardId3ReadingCharacterSet)->active;
 
-        USE_ID3_ISO_8859_1_CHARACTER_SET                = GTK_TOGGLE_BUTTON(UseId3ISO88591CharacterSet)->active;
-        USE_ID3_ISO_8859_1_THEN_UNICODE_CHARACTER_SET   = GTK_TOGGLE_BUTTON(UseId3ISO88591ThenUnicodeCharacterSet)->active;
-        USE_ID3_UNICODE_CHARACTER_SET                   = GTK_TOGGLE_BUTTON(UseId3UnicodeCharacterSet)->active;
-        USE_NON_STANDARD_ID3_READING_CHARACTER_SET      = GTK_TOGGLE_BUTTON(UseNonStandardId3ReadingCharacterSet)->active;
-        USE_NON_STANDARD_ID3_WRITING_CHARACTER_SET      = GTK_TOGGLE_BUTTON(UseNonStandardId3WritingCharacterSet)->active;
-
-        FILE_WRITING_CHARACTER_SET_OTHER                = GTK_TOGGLE_BUTTON(FileWritingCharacterSetOther)->active;
-        FILE_WRITING_CHARACTER_SET_APPROXIMATE          = GTK_TOGGLE_BUTTON(FileWritingCharacterSetApproximate)->active;
-        FILE_WRITING_CHARACTER_SET_DISCARD              = GTK_TOGGLE_BUTTON(FileWritingCharacterSetDiscard)->active;
-
-        temp = Get_Active_Combo_Box_Item(GTK_COMBO_BOX(FileReadingCharacterSetCombo));
-        ID3_FILE_READING_CHARACTER_SET = Charset_Get_Name_From_Title(temp);
+#ifdef ENABLE_ID3LIB
+        active = gtk_combo_box_get_active(GTK_COMBO_BOX(FileWritingId3v2VersionCombo));
+        FILE_WRITING_ID3V2_VERSION_4 = !active;
+#else
+        FILE_WRITING_ID3V2_VERSION_4 = 1;
+#endif
+        temp = Get_Active_Combo_Box_Item(GTK_COMBO_BOX(FileReadingId3v1v2CharacterSetCombo));
+        FILE_READING_ID3V1V2_CHARACTER_SET = Charset_Get_Name_From_Title(temp);
         g_free(temp);
 
-        temp = Get_Active_Combo_Box_Item(GTK_COMBO_BOX(FileWritingCharacterSetCombo));
-        ID3_FILE_WRITING_CHARACTER_SET = Charset_Get_Name_From_Title(temp);
+        FILE_WRITING_ID3V2_WRITE_TAG                 = GTK_TOGGLE_BUTTON(FileWritingId3v2WriteTag)->active;
+        FILE_WRITING_ID3V2_USE_CRC32                 = GTK_TOGGLE_BUTTON(FileWritingId3v2UseCrc32)->active;
+        FILE_WRITING_ID3V2_USE_COMPRESSION           = GTK_TOGGLE_BUTTON(FileWritingId3v2UseCompression)->active;
+        FILE_WRITING_ID3V2_USE_UNICODE_CHARACTER_SET = GTK_TOGGLE_BUTTON(FileWritingId3v2UseUnicodeCharacterSet)->active;
+
+        active = gtk_combo_box_get_active(GTK_COMBO_BOX(FileWritingId3v2UnicodeCharacterSetCombo));
+        FILE_WRITING_ID3V2_UNICODE_CHARACTER_SET     = (active == 1) ? "UTF-16" : "UTF-8";
+
+        temp = Get_Active_Combo_Box_Item(GTK_COMBO_BOX(FileWritingId3v2NoUnicodeCharacterSetCombo));
+        FILE_WRITING_ID3V2_NO_UNICODE_CHARACTER_SET  = Charset_Get_Name_From_Title(temp);
         g_free(temp);
 
+        FILE_WRITING_ID3V2_ICONV_OPTIONS_NO          = GTK_TOGGLE_BUTTON(FileWritingId3v2IconvOptionsNo)->active;
+        FILE_WRITING_ID3V2_ICONV_OPTIONS_TRANSLIT    = GTK_TOGGLE_BUTTON(FileWritingId3v2IconvOptionsTranslit)->active;
+        FILE_WRITING_ID3V2_ICONV_OPTIONS_IGNORE      = GTK_TOGGLE_BUTTON(FileWritingId3v2IconvOptionsIgnore)->active;
+
+        FILE_WRITING_ID3V1_WRITE_TAG                 = GTK_TOGGLE_BUTTON(FileWritingId3v1WriteTag)->active;
+        temp = Get_Active_Combo_Box_Item(GTK_COMBO_BOX(FileWritingId3v1CharacterSetCombo));
+        FILE_WRITING_ID3V1_CHARACTER_SET             = Charset_Get_Name_From_Title(temp);
+        g_free(temp);
+
+        FILE_WRITING_ID3V1_ICONV_OPTIONS_NO          = GTK_TOGGLE_BUTTON(FileWritingId3v1IconvOptionsNo)->active;
+        FILE_WRITING_ID3V1_ICONV_OPTIONS_TRANSLIT    = GTK_TOGGLE_BUTTON(FileWritingId3v1IconvOptionsTranslit)->active;
+        FILE_WRITING_ID3V1_ICONV_OPTIONS_IGNORE      = GTK_TOGGLE_BUTTON(FileWritingId3v1IconvOptionsIgnore)->active;
 
         /* Scanner */
         // Fill Tag Scanner
@@ -695,6 +748,9 @@ void Apply_Changes_Of_Preferences_Window (void)
         if (CDDB_SERVER_CGI_PATH_MANUAL_SEARCH) g_free(CDDB_SERVER_CGI_PATH_MANUAL_SEARCH);
         CDDB_SERVER_CGI_PATH_MANUAL_SEARCH = g_strdup(gtk_entry_get_text(GTK_ENTRY(CddbServerCgiPathManualSearch)));
 
+        if (CDDB_LOCAL_PATH) g_free(CDDB_LOCAL_PATH);
+        CDDB_LOCAL_PATH = g_strdup(gtk_entry_get_text(GTK_ENTRY(GTK_BIN(CddbLocalPath)->child)));
+
         CDDB_USE_PROXY       = GTK_TOGGLE_BUTTON(CddbUseProxy)->active;
         if (CDDB_PROXY_NAME) g_free(CDDB_PROXY_NAME);
         CDDB_PROXY_NAME      = g_strdup(gtk_entry_get_text(GTK_ENTRY(CddbProxyName)));
@@ -704,8 +760,8 @@ void Apply_Changes_Of_Preferences_Window (void)
         if (CDDB_PROXY_USER_PASSWORD) g_free(CDDB_PROXY_USER_PASSWORD);
         CDDB_PROXY_USER_PASSWORD      = g_strdup(gtk_entry_get_text(GTK_ENTRY(CddbProxyUserPassword)));
 
-        CDDB_FOLLOW_FILE    = GTK_TOGGLE_BUTTON(CddbFollowFile)->active;
-        CDDB_USE_DLM        = GTK_TOGGLE_BUTTON(CddbUseDLM)->active;
+        CDDB_FOLLOW_FILE      = GTK_TOGGLE_BUTTON(CddbFollowFile)->active;
+        CDDB_USE_DLM          = GTK_TOGGLE_BUTTON(CddbUseDLM)->active;
 
         /* Confirmation */
         CONFIRM_BEFORE_EXIT    = GTK_TOGGLE_BUTTON(ConfirmBeforeExit)->active;
@@ -811,12 +867,12 @@ void Save_Config_To_File (void)
     /* The file to write */
     if (!HOME_VARIABLE) return;
     file_path = g_strconcat(HOME_VARIABLE,
-                            HOME_VARIABLE[strlen(HOME_VARIABLE)-1]!=G_DIR_SEPARATOR?G_DIR_SEPARATOR_S:"",
+                            HOME_VARIABLE[strlen(HOME_VARIABLE)-1]!=G_DIR_SEPARATOR ? G_DIR_SEPARATOR_S : "",
                             CONFIG_FILE,NULL);
 
     if ( Create_Easytag_Directory()==0 || (file=fopen(file_path,"w+"))==0 )
     {
-        g_print(_("ERROR: Can't write config file: %s (%s)\n\a"),file_path,g_strerror(errno));
+        Log_Print(_("ERROR: Can't write config file: %s (%s)"),file_path,g_strerror(errno));
     }else
     {
         gint ConfigVarListLen = sizeof(Config_Variables)/sizeof(tConfigVariable);
@@ -859,8 +915,8 @@ void Save_Config_To_File (void)
                 }
                 default:
                 {
-                    g_print("ERROR: Can't save: type of config variable not supported "
-                            "for '%s'!\n\a",Config_Variables[i].name);
+                    Log_Print("ERROR: Can't save: type of config variable not supported "
+                              "for '%s'!",Config_Variables[i].name);
                     break;
                 }
             }
@@ -932,8 +988,8 @@ void Set_Config (gchar *line)
 
                 default:
                 {
-                    g_print("ERROR: Can't read: type of config variable not supported "
-                            "for '%s'!\n\a",Config_Variables[i].name);
+                    Log_Print("ERROR: Can't read: type of config variable not supported "
+                              "for '%s'!",Config_Variables[i].name);
                     break;
                 }
             }
@@ -959,8 +1015,8 @@ void Read_Config (void)
 
     if ( (file=fopen(file_path,"r"))==0 )
     {
-        g_print(_("\nCan't open configuration file '%s' (%s)\n"),file_path,g_strerror(errno));
-        g_print(_("Loading default configuration...\n"));
+        Log_Print(_("Can't open configuration file '%s' (%s)"),file_path,g_strerror(errno));
+        Log_Print(_("Loading default configuration..."));
     }else
     {
         while (fgets(buffer,sizeof(buffer),file))
@@ -996,7 +1052,7 @@ void Display_Config (void)
 
     if ( (file=fopen(file_path,"r"))==0 )
     {
-        g_print("Can't open configuration file '%s' (%s)\n",file_path,g_strerror(errno));
+        g_print(_("Can't open configuration file '%s' (%s)"),file_path,g_strerror(errno));
     }else
     {
         gint ConfigVarListLen = sizeof(Config_Variables)/sizeof(tConfigVariable);
@@ -1060,114 +1116,122 @@ gboolean Setting_Create_Files (void)
     if ( (file=fopen(file_path,"a+")) != NULL )
         fclose(file);
     else
-        g_print(_("Can't create or open file '%s' (%s)\n"),CONFIG_FILE,g_strerror(errno));
+        Log_Print(_("Can't create or open file '%s' (%s)"),CONFIG_FILE,g_strerror(errno));
     g_free(file_path);
 
     file_path = g_strconcat(home_path,SCAN_TAG_MASKS_FILE,NULL);
     if ( (file=fopen(file_path,"a+")) != NULL )
         fclose(file);
     else
-        g_print(_("Can't create or open file '%s' (%s)\n"),SCAN_TAG_MASKS_FILE,g_strerror(errno));
+        Log_Print(_("Can't create or open file '%s' (%s)"),SCAN_TAG_MASKS_FILE,g_strerror(errno));
     g_free(file_path);
 
     file_path = g_strconcat(home_path,RENAME_FILE_MASKS_FILE,NULL);
     if ( (file=fopen(file_path,"a+")) != NULL )
         fclose(file);
     else
-        g_print(_("Can't create or open file '%s' (%s)\n"),RENAME_FILE_MASKS_FILE,g_strerror(errno));
+        Log_Print(_("Can't create or open file '%s' (%s)"),RENAME_FILE_MASKS_FILE,g_strerror(errno));
     g_free(file_path);
 
     file_path = g_strconcat(home_path,RENAME_DIRECTORY_MASKS_FILE,NULL);
     if ( (file=fopen(file_path,"a+")) != NULL )
         fclose(file);
     else
-        g_print(_("Can't create or open file '%s' (%s)\n"),RENAME_DIRECTORY_MASKS_FILE,g_strerror(errno));
+        Log_Print(_("Can't create or open file '%s' (%s)"),RENAME_DIRECTORY_MASKS_FILE,g_strerror(errno));
     g_free(file_path);
 
     file_path = g_strconcat(home_path,DEFAULT_PATH_TO_MP3_HISTORY_FILE,NULL);
     if ( (file=fopen(file_path,"a+")) != NULL )
         fclose(file);
     else
-        g_print(_("Can't create or open file '%s' (%s)\n"),DEFAULT_PATH_TO_MP3_HISTORY_FILE,g_strerror(errno));
+        Log_Print(_("Can't create or open file '%s' (%s)"),DEFAULT_PATH_TO_MP3_HISTORY_FILE,g_strerror(errno));
     g_free(file_path);
 
     file_path = g_strconcat(home_path,DEFAULT_TAG_COMMENT_HISTORY_FILE,NULL);
     if ( (file=fopen(file_path,"a+")) != NULL )
         fclose(file);
     else
-        g_print(_("Can't create or open file '%s' (%s)\n"),DEFAULT_TAG_COMMENT_HISTORY_FILE,g_strerror(errno));
+        Log_Print(_("Can't create or open file '%s' (%s)"),DEFAULT_TAG_COMMENT_HISTORY_FILE,g_strerror(errno));
     g_free(file_path);
 
     file_path = g_strconcat(home_path,PATH_ENTRY_HISTORY_FILE,NULL);
     if ( (file=fopen(file_path,"a+")) != NULL )
         fclose(file);
     else
-        g_print(_("Can't create or open file '%s' (%s)\n"),PATH_ENTRY_HISTORY_FILE,g_strerror(errno));
+        Log_Print(_("Can't create or open file '%s' (%s)"),PATH_ENTRY_HISTORY_FILE,g_strerror(errno));
     g_free(file_path);
 
     file_path = g_strconcat(home_path,PLAY_LIST_NAME_MASKS_FILE,NULL);
     if ( (file=fopen(file_path,"a+")) != NULL )
         fclose(file);
     else
-        g_print(_("Can't create or open file '%s' (%s)\n"),PLAY_LIST_NAME_MASKS_FILE,g_strerror(errno));
+        Log_Print(_("Can't create or open file '%s' (%s)"),PLAY_LIST_NAME_MASKS_FILE,g_strerror(errno));
     g_free(file_path);
 
     file_path = g_strconcat(home_path,RUN_PROGRAM_WITH_DIRECTORY_HISTORY_FILE,NULL);
     if ( (file=fopen(file_path,"a+")) != NULL )
         fclose(file);
     else
-        g_print(_("Can't create or open file '%s' (%s)\n"),RUN_PROGRAM_WITH_DIRECTORY_HISTORY_FILE,g_strerror(errno));
+        Log_Print(_("Can't create or open file '%s' (%s)"),RUN_PROGRAM_WITH_DIRECTORY_HISTORY_FILE,g_strerror(errno));
     g_free(file_path);
 
     file_path = g_strconcat(home_path,RUN_PROGRAM_WITH_FILE_HISTORY_FILE,NULL);
     if ( (file=fopen(file_path,"a+")) != NULL )
         fclose(file);
     else
-        g_print(_("Can't create or open file '%s' (%s)\n"),RUN_PROGRAM_WITH_FILE_HISTORY_FILE,g_strerror(errno));
+        Log_Print(_("Can't create or open file '%s' (%s)"),RUN_PROGRAM_WITH_FILE_HISTORY_FILE,g_strerror(errno));
     g_free(file_path);
 
     file_path = g_strconcat(home_path,AUDIO_FILE_PLAYER_HISTORY_FILE,NULL);
     if ( (file=fopen(file_path,"a+")) != NULL )
         fclose(file);
     else
-        g_print(_("Can't create or open file '%s' (%s)\n"),AUDIO_FILE_PLAYER_HISTORY_FILE,g_strerror(errno));
+        Log_Print(_("Can't create or open file '%s' (%s)"),AUDIO_FILE_PLAYER_HISTORY_FILE,g_strerror(errno));
     g_free(file_path);
 
     file_path = g_strconcat(home_path,SEARCH_FILE_HISTORY_FILE,NULL);
     if ( (file=fopen(file_path,"a+")) != NULL )
         fclose(file);
     else
-        g_print(_("Can't create or open file '%s' (%s)\n"),SEARCH_FILE_HISTORY_FILE,g_strerror(errno));
+        Log_Print(_("Can't create or open file '%s' (%s)"),SEARCH_FILE_HISTORY_FILE,g_strerror(errno));
     g_free(file_path);
 
     file_path = g_strconcat(home_path,FILE_TO_LOAD_HISTORY_FILE,NULL);
     if ( (file=fopen(file_path,"a+")) != NULL )
         fclose(file);
     else
-        g_print(_("Can't create or open file '%s' (%s)\n"),FILE_TO_LOAD_HISTORY_FILE,g_strerror(errno));
+        Log_Print(_("Can't create or open file '%s' (%s)"),FILE_TO_LOAD_HISTORY_FILE,g_strerror(errno));
     g_free(file_path);
 
     file_path = g_strconcat(home_path,PLAYLIST_CONTENT_MASKS_FILE,NULL);
     if ( (file=fopen(file_path,"a+")) != NULL )
         fclose(file);
     else
-        g_print(_("Can't create or open file '%s' (%s)\n"),PLAYLIST_CONTENT_MASKS_FILE,g_strerror(errno));
+        Log_Print(_("Can't create or open file '%s' (%s)"),PLAYLIST_CONTENT_MASKS_FILE,g_strerror(errno));
     g_free(file_path);
 
     file_path = g_strconcat(home_path,CDDB_SEARCH_STRING_HISTORY_FILE,NULL);
     if ( (file=fopen(file_path,"a+")) != NULL )
         fclose(file);
     else
-        g_print(_("Can't create or open file '%s' (%s)\n"),CDDB_SEARCH_STRING_HISTORY_FILE,g_strerror(errno));
+        Log_Print(_("Can't create or open file '%s' (%s)"),CDDB_SEARCH_STRING_HISTORY_FILE,g_strerror(errno));
     g_free(file_path);
 
     file_path = g_strconcat(home_path,CDDB_SEARCH_STRING_IN_RESULT_HISTORY_FILE,NULL);
     if ( (file=fopen(file_path,"a+")) != NULL )
         fclose(file);
     else
-        g_print(_("Can't create or open file '%s' (%s)\n"),CDDB_SEARCH_STRING_IN_RESULT_HISTORY_FILE,g_strerror(errno));
+        Log_Print(_("Can't create or open file '%s' (%s)"),CDDB_SEARCH_STRING_IN_RESULT_HISTORY_FILE,g_strerror(errno));
     g_free(file_path);
 
+    file_path = g_strconcat(home_path,CDDB_LOCAL_PATH_HISTORY_FILE,NULL);
+    if ( (file=fopen(file_path,"a+")) != NULL )
+        fclose(file);
+    else
+        Log_Print(_("Can't create or open file '%s' (%s)"),CDDB_LOCAL_PATH_HISTORY_FILE,g_strerror(errno));
+    g_free(file_path);
+
+
     g_free(home_path);
 
     return TRUE;
@@ -1197,7 +1261,7 @@ void Save_List_Store_To_File (gchar *filename, GtkListStore *liststore, gint col
 
     if ( Create_Easytag_Directory()==0 || (file=fopen(file_path,"w+"))==NULL )
     {
-        g_print(_("ERROR: Can't write list to file: %s (%s)\n\a"),file_path,g_strerror(errno));
+        Log_Print(_("ERROR: Can't write list to file: %s (%s)"),file_path,g_strerror(errno));
     }else
     {
         do
@@ -1237,7 +1301,7 @@ gboolean Populate_List_Store_From_File (gchar *filename, GtkListStore *liststore
 
     if ( (file=fopen(file_path,"r"))==NULL )
     {
-        g_print(_("Can't open file '%s' (%s)\n"),file_path,g_strerror(errno));
+        Log_Print(_("Can't open file '%s' (%s)"),file_path,g_strerror(errno));
     }else
     {
         gchar *data = NULL;
@@ -1277,7 +1341,7 @@ void Load_Scan_Tag_Masks_List (GtkListStore *liststore, gint colnum, gchar **fal
     if (!Populate_List_Store_From_File(SCAN_TAG_MASKS_FILE, liststore, colnum))
     {
         // Fall back to defaults
-        g_print(_("Loading default 'Fill Tag' masks...\n"));
+        Log_Print(_("Loading default 'Fill Tag' masks..."));
 
         while(fallback[i])
         {
@@ -1305,7 +1369,7 @@ void Load_Rename_File_Masks_List (GtkListStore *liststore, gint colnum, gchar **
     if (!Populate_List_Store_From_File(RENAME_FILE_MASKS_FILE, liststore, colnum))
     {
         // Fall back to defaults
-        g_print(_("Loading default 'Rename File' masks...\n"));
+        Log_Print(_("Loading default 'Rename File' masks..."));
 
         while(fallback[i])
         {
@@ -1332,7 +1396,7 @@ void Load_Rename_Directory_Masks_List (GtkListStore *liststore, gint colnum, gch
     if (!Populate_List_Store_From_File(RENAME_DIRECTORY_MASKS_FILE, liststore, colnum))
     {
         // Fall back to defaults
-        g_print(_("Loading default 'Rename Directory' masks...\n"));
+        Log_Print(_("Loading default 'Rename Directory' masks..."));
 
         while(fallback[i])
         {
@@ -1495,6 +1559,20 @@ void Save_Cddb_Search_String_In_Result_List (GtkListStore *liststore, gint colnu
     Save_List_Store_To_File(CDDB_SEARCH_STRING_IN_RESULT_HISTORY_FILE, liststore, colnum);
 }
 
+/*
+ * Functions for writing and reading list of 'CddbLocalPath3' combobox
+ */
+void Load_Cddb_Local_Path_List (GtkListStore *liststore, gint colnum)
+{
+    Populate_List_Store_From_File(CDDB_LOCAL_PATH_HISTORY_FILE, liststore, colnum);
+}
+void Save_Cddb_Local_Path_List (GtkListStore *liststore, gint colnum)
+{
+    Save_List_Store_To_File(CDDB_LOCAL_PATH_HISTORY_FILE, liststore, colnum);
+}
+
+
+
 
 
 
@@ -1511,7 +1589,7 @@ gboolean Create_Easytag_Directory (void)
 
     if (!HOME_VARIABLE)
     {
-        g_print(_("ERROR: The environment variable HOME is not defined!\n\n"));
+        Log_Print(_("ERROR: The environment variable HOME is not defined!"));
         return FALSE;
     }
 
@@ -1527,7 +1605,7 @@ gboolean Create_Easytag_Directory (void)
     {
         if ( (mkdir(easytag_path,S_IRWXU|S_IXGRP|S_IRGRP)) == -1)
         {
-            g_print(_("ERROR: Can't create directory '%s' (%s)!\n"),easytag_path,g_strerror(errno));
+            Log_Print(_("ERROR: Can't create directory '%s' (%s)!"),easytag_path,g_strerror(errno));
             return FALSE;
         }
     }else
