@@ -67,6 +67,7 @@ gint    MAIN_WINDOW_WIDTH;
 gint    PANE_HANDLE_POSITION1;
 gint    PANE_HANDLE_POSITION2;
 gint    PANE_HANDLE_POSITION3;
+gint    PANE_HANDLE_POSITION4;
 gint    SHOW_HEADER_INFO;
 
 gint    CHANGED_FILES_DISPLAYED_TO_RED;
@@ -88,26 +89,36 @@ gint    FILENAME_EXTENSION_LOWER_CASE;
 gint    FILENAME_EXTENSION_UPPER_CASE;
 gint    FILENAME_EXTENSION_NO_CHANGE;
 gint    PRESERVE_MODIFICATION_TIME;
+gint    UPDATE_PARENT_DIRECTORY_MODIFICATION_TIME;
 
 gint    FILENAME_CHARACTER_SET_OTHER;
 gint    FILENAME_CHARACTER_SET_APPROXIMATE;
 gint    FILENAME_CHARACTER_SET_DISCARD;
 
 /* Tag Settings */
-gint    WRITE_ID3V1_TAG;
-gint    WRITE_ID3V2_TAG;
 gint    WRITE_ID3_TAGS_IN_FLAC_FILE;
-gint    USE_ID3V2_PADDING;
 gint    STRIP_TAG_WHEN_EMPTY_FIELDS;
 gint    CONVERT_OLD_ID3V2_TAG_VERSION;
 
-gint    USE_ID3_ISO_8859_1_CHARACTER_SET;
-gint    USE_ID3_ISO_8859_1_THEN_UNICODE_CHARACTER_SET;
-gint    USE_ID3_UNICODE_CHARACTER_SET;
+gint    FILE_WRITING_ID3V2_VERSION_4;
 gint    USE_NON_STANDARD_ID3_READING_CHARACTER_SET;
-gint    USE_NON_STANDARD_ID3_WRITING_CHARACTER_SET;
-gchar  *ID3_FILE_READING_CHARACTER_SET;
-gchar  *ID3_FILE_WRITING_CHARACTER_SET;
+gchar  *FILE_READING_ID3V1V2_CHARACTER_SET;
+
+gint    FILE_WRITING_ID3V2_WRITE_TAG;
+gint    FILE_WRITING_ID3V2_USE_CRC32;
+gint    FILE_WRITING_ID3V2_USE_COMPRESSION;
+gint    FILE_WRITING_ID3V2_USE_UNICODE_CHARACTER_SET;
+gchar  *FILE_WRITING_ID3V2_UNICODE_CHARACTER_SET;
+gchar  *FILE_WRITING_ID3V2_NO_UNICODE_CHARACTER_SET;
+gint    FILE_WRITING_ID3V2_ICONV_OPTIONS_NO;
+gint    FILE_WRITING_ID3V2_ICONV_OPTIONS_TRANSLIT;
+gint    FILE_WRITING_ID3V2_ICONV_OPTIONS_IGNORE;
+
+gint    FILE_WRITING_ID3V1_WRITE_TAG;
+gchar  *FILE_WRITING_ID3V1_CHARACTER_SET;
+gint    FILE_WRITING_ID3V1_ICONV_OPTIONS_NO;
+gint    FILE_WRITING_ID3V1_ICONV_OPTIONS_TRANSLIT;
+gint    FILE_WRITING_ID3V1_ICONV_OPTIONS_IGNORE;
 
 gint    DATE_AUTO_COMPLETION;
 gint    NUMBER_TRACK_FORMATED;
@@ -116,10 +127,6 @@ gint    OGG_TAG_WRITE_XMMS_COMMENT;
 gint    SET_FOCUS_TO_SAME_TAG_FIELD;
 gint    SET_FOCUS_TO_FIRST_TAG_FIELD;
 
-gint    FILE_WRITING_CHARACTER_SET_OTHER;
-gint    FILE_WRITING_CHARACTER_SET_APPROXIMATE;
-gint    FILE_WRITING_CHARACTER_SET_DISCARD;
-
 
 /* Scanner */
 gint    SCANNER_TYPE;
@@ -184,9 +191,19 @@ gint    PLAYLIST_CONTENT_FILENAME;
 gint    PLAYLIST_CONTENT_MASK;
 gchar  *PLAYLIST_CONTENT_MASK_VALUE;
 
+gint    PLAYLIST_WINDOW_X;
+gint    PLAYLIST_WINDOW_Y;
+gint    PLAYLIST_WINDOW_WIDTH;
+gint    PLAYLIST_WINDOW_HEIGHT;
+
 /* "Load filenames from txt" window */
 gint    LOAD_FILE_RUN_SCANNER;
 
+gint    LOAD_FILE_WINDOW_X;
+gint    LOAD_FILE_WINDOW_Y;
+gint    LOAD_FILE_WINDOW_WIDTH;
+gint    LOAD_FILE_WINDOW_HEIGHT;
+
 /* CDDB in preferences window */
 gchar  *CDDB_SERVER_NAME_AUTOMATIC_SEARCH;
 gint    CDDB_SERVER_PORT_AUTOMATIC_SEARCH;
@@ -197,6 +214,7 @@ gchar  *CDDB_SERVER_CGI_PATH_AUTOMATIC_SEARCH2;
 gchar  *CDDB_SERVER_NAME_MANUAL_SEARCH;
 gint    CDDB_SERVER_PORT_MANUAL_SEARCH;
 gchar  *CDDB_SERVER_CGI_PATH_MANUAL_SEARCH;
+gchar  *CDDB_LOCAL_PATH;
 gint    CDDB_USE_PROXY;
 gchar  *CDDB_PROXY_NAME;
 gint    CDDB_PROXY_PORT;
@@ -212,6 +230,7 @@ gint    CDDB_PANE_HANDLE_POSITION;
 
 gint    CDDB_FOLLOW_FILE;
 gint    CDDB_USE_DLM;
+gint    CDDB_USE_LOCAL_ACCESS;
 
 /* CDDB window */
 gint    CDDB_SEARCH_IN_ALL_FIELDS;
@@ -348,5 +367,10 @@ void Save_Cddb_Search_String_List (GtkListStore *liststore, gint colnum);
 void Load_Cddb_Search_String_In_Result_List (GtkListStore *liststore, gint colnum);
 void Save_Cddb_Search_String_In_Result_List (GtkListStore *liststore, gint colnum);
 
+/* 'CddbLocalPath' combobox */
+void Load_Cddb_Local_Path_List (GtkListStore *liststore, gint colnum);
+void Save_Cddb_Local_Path_List (GtkListStore *liststore, gint colnum);
+
+
 
 #endif /* __CONFIG_H__ */
