@@ -44,13 +44,19 @@
 #endif
 #include <gdk/gdkwin32.h>
 
+#include "resource.h"
+//#include "../log.h"
+
 #include <libintl.h>
 
+#include "win32dep.h"
+
 /*
  *  DEFINES & MACROS
  */
 #define _(x) gettext(x)
 
+
 /*
  * DATA STRUCTS
  */
@@ -133,9 +139,12 @@ char* ET_Win32_Escape_Dirsep (char* filename )
 int gettimeofday (struct timeval *t, void *foo)
 {
     struct _timeb temp;
-    _ftime(&temp);
-    t->tv_sec = temp.time;
-    t->tv_usec = temp.millitm * 1000;
+
+	if (t != 0) {
+        _ftime(&temp);
+        t->tv_sec = temp.time;              /* seconds since 1-1-1970 */
+        t->tv_usec = temp.millitm * 1000; 	/* microseconds */
+    }
     return (0);
 }
 
@@ -164,24 +173,32 @@ FARPROC ET_Win32_Find_And_Loadproc ( char* dllname, char* procedure )
 
     if(!(hmod=GetModuleHandle(dllname)))
     {
-        g_printf("%s not found. Loading it..\n", dllname);
+        //Log_Print(_("DLL '%s' not found. Try loading it..."), dllname);
+        g_printf(_("DLL '%s' not found. Try loading it..."), dllname);
+        g_print("\n");
         if(!(hmod = LoadLibrary(dllname)))
         {
-            g_print("Could not load: %s\n", dllname);
+            //Log_Print(_("DLL '%s' could not be loaded"), dllname);
+            g_print(_("DLL '%s' could not be loaded"), dllname);
+            g_print("\n");
             return NULL;
         }
         else
-            did_load = 1;
+			did_load = TRUE;
     }
 
     if((proc=GetProcAddress(hmod, procedure)))
     {
-        g_print("This version of %s contains %s\n", dllname, procedure);
+        //Log_Print(_("This version of '%s' contains '%s'"), dllname, procedure);
+        g_print(_("This version of '%s' contains '%s'"), dllname, procedure);
+        g_print("\n");
         return proc;
     }
     else
     {
-        g_print("Function %s not found in dll %s\n", procedure, dllname);
+        //Log_Print(_("Function '%s' not found in dll '%s'"), procedure, dllname);
+        g_print(_("Function '%s' not found in dll '%s'"), procedure, dllname);
+        g_print("\n");
         if(did_load)
         {
             /* unload dll */
@@ -202,6 +219,7 @@ char* ET_Win32_Install_Dir (void)
     if ( hmod == 0 )
     {
         buf = g_win32_error_message( GetLastError() );
+        //Log_Print("GetModuleHandle error: %s\n", buf);
         g_print("GetModuleHandle error: %s\n", buf);
         g_free(buf);
         return NULL;
@@ -209,6 +227,7 @@ char* ET_Win32_Install_Dir (void)
     if (GetModuleFileName( hmod, (char*)&install_dir, MAXPATHLEN ) == 0)
     {
         buf = g_win32_error_message( GetLastError() );
+        //Log_Print("GetModuleFileName error: %s\n", buf);
         g_print("GetModuleFileName error: %s\n", buf);
         g_free(buf);
         return NULL;
@@ -271,7 +290,9 @@ char*  ET_Win32_Get_Audio_File_Player (void)
         player = g_strdup("");
     }
      
-    g_print("Audio player : %s\n", player);
+    //Log_Print(_("Audio player: '%s'"), player);
+    g_print(_("Audio player: '%s'"), player);
+    g_print("\n");
 
     return player;
 }
@@ -293,7 +314,8 @@ void ET_Win32_Notify_Uri (const char *uri)
        default http browser.
     */
     if(!ShellExecuteEx(&sinfo))
-        g_printf("Error opening URI: %s error: %d\n", uri, (int)sinfo.hInstApp);
+        //Log_Print("Error opening URI: %s error: %d\n", uri, (int)sinfo.hInstApp);
+        g_print("Error opening URI: %s error: %d\n", uri, (int)sinfo.hInstApp);
 }
 
 
@@ -408,11 +430,13 @@ void ET_Win32_Init (HINSTANCE hint)
 
     //ET_Win32_Path_Replace_Backslashes(app_data_dir);
 
-    g_print("HOME dir for settings: %s\n", app_data_dir);
+    //Log_Print(_("EasyTAG settings dir: '%s'"), app_data_dir);
+    g_print(_("EasyTAG settings dir: '%s'"), app_data_dir);
+    g_print("\n");
 
     newenv = g_strdup_printf("HOME=%s", app_data_dir);
 
-    if(putenv(newenv)<0)
+    if (putenv(newenv)<0)
         g_print("putenv failed\n");
     g_free(newenv);
 
@@ -432,3 +456,38 @@ BOOL WINAPI DllMain ( HINSTANCE hinstDLL, DWORD fdwReason, LPVOID lpvReserved )
     ET_dll_hInstance = hinstDLL;
     return TRUE;
 }
+
+
+/*
+ * Copyright (C) 2002     Manuel Novoa III
+ * Copyright (C) 2000-2005 Erik Andersen <andersen@uclibc.org>
+ *
+ * Licensed under the LGPL v2.1, see the file COPYING.LIB in this tarball.
+ */
+
+#include <string.h>
+#include <ctype.h>
+
+char *strcasestr(const char *s1, const char *s2)
+{
+	register const char *s = s1;
+	register const char *p = s2;
+
+	do {
+		if (!*p) {
+			return (char *) s1;;
+		}
+		if ((*p == *s)
+			|| (tolower(*((unsigned char *)p)) == tolower(*((unsigned char *)s)))
+			) {
+			++p;
+			++s;
+		} else {
+			p = s2;
+			if (!*s) {
+				return NULL;
+			}
+			s = ++s1;
+		}
+	} while (1);
+}
\ No newline at end of file
