@@ -22,6 +22,8 @@
  */
 #ifndef _WIN32DEP_H_
 #define _WIN32DEP_H_
+
+
 #include <winsock2.h>
 #include <process.h>
 #include <gtk/gtk.h>
@@ -32,6 +34,11 @@
 #define chown(a,b,c)
 #define chmod(a,b)
 
+//#define strcasestr(haystack, needle) strstr(haystack, needle)
+char *strcasestr(const char *s1, const char *s2);
+
+
+
 /*
  *  PROTOS
  */
@@ -59,9 +66,10 @@ extern void      ET_Win32_Notify_Uri (const char *uri);
 extern void      ET_Win32_Init    (HINSTANCE);
 extern void      ET_Win32_Cleanup (void);
 
-extern void      ET_Win32_Path_Remove_Trailing_Slash (gchar *path);
-extern void      ET_Win32_Path_Replace_Backslashes   (gchar *path);
-extern void      ET_Win32_Path_Replace_Slashes       (gchar *path);
+extern void      ET_Win32_Path_Remove_Trailing_Slash     (gchar *path);
+extern void      ET_Win32_Path_Remove_Trailing_Backslash (gchar *path);
+extern void      ET_Win32_Path_Replace_Backslashes       (gchar *path);
+extern void      ET_Win32_Path_Replace_Slashes           (gchar *path);
 
 /*
  *  MACROS
