@@ -66,6 +66,7 @@ typedef BOOL (CALLBACK* LPFNATTACHCONSOLE)(DWORD);
 static LPFNEASYTAGMAIN easytag_main = NULL;
 static LPFNSETDLLDIRECTORY MySetDllDirectory = NULL;
 
+
 static const char *get_win32_error_message(DWORD err) {
 	static char err_msg[512];
 
@@ -91,7 +92,7 @@ static BOOL read_reg_string(HKEY key, char* sub_key, char* val_name, LPBYTE data
 		else {
 			const char *err_msg = get_win32_error_message(retv);
 
-			printf("Could not read reg key '%s' subkey '%s' value: '%s'.\nMessage: (%ld) %s\n",
+			printf("Could not read reg key '%s' subkey '%s' value: '%s'. Message: (%ld) %s\n",
 					((key == HKEY_LOCAL_MACHINE) ? "HKLM" :
 					 (key == HKEY_CURRENT_USER) ? "HKCU" :
 					 "???"),
@@ -104,7 +105,7 @@ static BOOL read_reg_string(HKEY key, char* sub_key, char* val_name, LPBYTE data
 
 		FormatMessage(FORMAT_MESSAGE_FROM_SYSTEM, NULL, retv, 0,
 				(LPTSTR) &szBuf, sizeof(szBuf), NULL);
-        printf("Could not open reg subkey: '%s'\nError: (%ld) %s\n",
+        printf("Could not open reg subkey: '%s'. Error: (%ld) %s\n",
 				sub_key, retv, szBuf);
 	}
 
@@ -365,7 +366,7 @@ static const char *get_locale() {
 
 	/* Check if user set EASYTAGLANG env var */
 	if ((locale = getenv("EASYTAGLANG"))) {
-		printf("Variable EASYTAGLANG defined: %s\n",locale);
+		printf("Variable EASYTAGLANG defined: '%s'\n",locale);
 		return locale;
 	}else
 		printf("Variable EASYTAGLANG not defined\n");
@@ -515,7 +516,7 @@ WinMain (struct HINSTANCE__ *hInstance, struct HINSTANCE__ *hPrevInstance,
 		DWORD dw = GetLastError();
 		const char *err_msg = get_win32_error_message(dw);
 		snprintf(errbuf, 512,
-			"Error getting module filename.\nError: (%u) %s",
+			"Error getting module filename. Error: (%u) %s",
 			(UINT) dw, err_msg);
 		printf(errbuf);
 		MessageBox(NULL, errbuf, NULL, MB_OK | MB_TOPMOST);
@@ -542,7 +543,7 @@ WinMain (struct HINSTANCE__ *hInstance, struct HINSTANCE__ *hPrevInstance,
 		BOOL mod_not_found = (dw == ERROR_MOD_NOT_FOUND || dw == ERROR_DLL_NOT_FOUND);
 		const char *err_msg = get_win32_error_message(dw);
 
-		snprintf(errbuf, 512, "Error loading easytag.dll.\nError: (%u) %s%s%s",
+		snprintf(errbuf, 512, "Error loading 'easytag.dll'. Error: (%u) %s%s%s",
 			(UINT) dw, err_msg,
 			mod_not_found ? "\n" : "",
 			mod_not_found ? "This probably means that GTK+ can't be found." : "");
